/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvSignalTabread.h"
#include "HvControlVar.h"
#include "HvSignalPhasor.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"
#include "HvControlPack.h"
#include "HvControlBinop.h"
#include "HvControlRandom.h"
#include "HvControlDelay.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvControlSlice.h"
#include "HvControlTabhead.h"
#include "HvTable.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_Yedrrxkn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gZUGTgm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ProoUtgo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JNd2fTIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k7dCR3ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IUhFTGy8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_F0r46CoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Fwb5ae2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0lEnlZE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JnOPKHnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S9ONFFOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Xb4BW88J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kkHDjP8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ur0KaIOa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_26O5jsdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_24njKF1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yXe8bwmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shKCQfDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vIfFd1s4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mGendXed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M1kdMhwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KsOLbx7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z29I73fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_h1CF8Cpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6T51SsZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1b6EwfW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PBWWxa2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X5bXbPgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_048U9e46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1jYYRNr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7oxPg944_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6tDQkw64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Gnpod2FX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BP2oDJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X6WOiSgq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cWpYC41b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TSrpXIjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NWPNJkR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Pk0tFbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aiTRoOhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fa9oVkIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MoSASh9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpDYt4Z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rflEmdDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KGKktrXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fZXOetaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4PVtYCbu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_UwJ1aWu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0OxoIgYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uxT8Lbbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G4sj1UIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vv9gVl7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3q0Jcyol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SXpljoXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ssfaH7az_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hh3uaHGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JFbfVUfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5iuNdZeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G8c9hrEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uHLJusX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HUdAPzfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tQCBkGXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnO6Bm3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ew1cUWot_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9GVFdYr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aZ9GTpsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_v033bRGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_gvIK9KGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qQJ9dGdI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_E4nvqz4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HepXD9y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oX1EbAmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qn0nhEVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IEVN1eYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buiUPQ5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ofzd7vKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nuCJFK4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DOWS8B1x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_eflvBCvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OVU8L592_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xEucgYjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AFI9dnfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TdTDAkDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ESq0zOdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_CRiwZOJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AOJnu09I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DuTlKZTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4vNNu83H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HA6HB1VL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RPHHK0Vv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5QMCizw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gOuf8H5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AO4zmk6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QbPXSofw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r6JwbzY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BlRB2qin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jFXiQ9MY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_we6Ffhmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eBTx9u9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jUFAFqju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_62gc3yjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6l2SZDkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AsSnykBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_wJUHA0Xm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCaRy48M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XEfPSm4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mR3M6NPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_93CBjlX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nt74d6V1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSnzYtxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wMduhJ4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6kXR7fiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aI3tJv1i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j6YHbu4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHPwxFCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZeT7TFUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_pYjuD1Jl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QGUwlcgd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aoCO63iL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s43ZImzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MN748Cqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_B19PdBiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_H3Au2zq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JSkp9Za7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CdfcFzSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlFoZrvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yLZnLteg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TxDaIDUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c6bvOwwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQLogK9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YOctYB71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q21nJ7v0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MYfhARHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bmkPs86X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KzLWzBFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_9cmRcgH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cigfwYdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TEwOnO7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V8VzwWZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6eLESJEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_568j2KzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_OG6LvJkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xkgton2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8y418CO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TqOi6g3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VeYdl1av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e9ZPsS3n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Glb3RIin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6uOdyVRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKYWKJBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4wRZpL9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XzqU1BZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xms2rKwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EfIhHHdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SW7t7wQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7ibS7czn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ONEXBuKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9ZsBeMr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_anozbq3d_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_4APvdDQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_SPM6X5xU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tpdqackN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_astcxfBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tFHAEGae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kvHhvUMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_So1TKFte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_24jLh7To_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V9pHsvuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Qt4lKLuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2V7O477o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hAvMymTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LtfjcJCX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_YLrwOTH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_FFckGgqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7RaRvHAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_revuQffC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gmqSR3kf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N9dfjg8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BwjKrXuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jsx9L667_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zOWeDKNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wPOmEV4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BH9TrJaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bxZ3lice_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uQGvN0JO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_70jGa3tE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_UzNda0mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X0QdYI64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VTDYpyRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_odl1SLLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qErT4d2k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lvJ0vASf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_553ZOStN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U1vGPCXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_w6n7BlAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9SvPVVOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qV4DjCLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oFAynuqC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bymITcNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WugpC00k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MZ6Rij2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zEirnjGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CUJCs5s1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3CAAdzd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QbcOOVoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mhkv4y0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_w5DLKjzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_X68bxY3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R3Vfejp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rCGsVz2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mLVPu7ku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fdQY7HYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_U1VwRZQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQrik1Id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uj0glqiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qPR0sb7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QbawmBWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LEfvNqvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WvWIhpG2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H3wDlbzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l8j2KzQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FJbdrw8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zdFYPJ2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_85X5llo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6cM78XlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fK0HX5kI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CFaC3mov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UB2ZegSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_i0uPTQvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SXJiR44u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MjrxypN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Yhit9pKm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_NkyFL5G0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_eINhsJT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0pEE7lv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IRc7HR5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kXhQ4PIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z72Bg5cB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nhoFWE29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKYlwZzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_t6XdP8hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cmgcSoFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VCS96T8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uJ1HeKY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3fcikbIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UICYZ62b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_8oOCCrlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LHoeIwm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nxN7tkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F6WuLR2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Cy0DYGL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yud9D33B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7JTjqugy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fizLJ01M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KhVIobJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1PkCUvyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AcfA55bP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wfesOiGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sirUNAyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q47XnGeU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KWp96wPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_H6FkY3i2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PANENFLh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tr8Phvp5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_yX84qXem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_I8YNsA5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0r3mJZDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QGs8S2Y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_moQjoxf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aDteivfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vl6RJwGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OWuQcHAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_81nqNms3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iIybrJNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2XpqifKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_smL22Bux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6AX9AusA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vQaCegpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Etj4xFi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHkkeRxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_93NAYrqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F7fFx8gd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BY1NfSz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0xvC3nkM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HbwNUE2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WShJ9blQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HBF9oU5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7obWn091_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Ex78Xs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hbCc5OQA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1vojhamF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VdZEjLNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yx8FrdSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yfFJtGZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6hgJNb5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s2c5Ys1e_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9pqlLOE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_nVqeN0aT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eLgK7jWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yhdfXW5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bSl8prbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZY1oYFdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_itKaRhhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iRe3PT1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UnUc8etL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VVRhIFY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tUrCPhvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_R2urZoI7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VFPMjpeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_L28301ei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_T6J56BhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmW00iAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o1rt35EO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fSabaBDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Unfh4lUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qJDrLvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JDzL2xoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_40WSJGej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W2nkemya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A8eOQbhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Za5rj3zX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xw3yXoQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Czgebpwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MIFdkZeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4pAm1psI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EaCE73qJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_06PUTPOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wb3rluwA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_aiXq7RAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dsSyN1WZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TajVQ5kT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBXyUs2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fViFmrpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GFsL275G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T7k9b6dJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZM25GXMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_4d3kI8dD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1TQkYi04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3PXAoRg5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DFw62a3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EsuSdWTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8OCxHb3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_MipP36Ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WOrt9548_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yXsYLydm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qyP12NAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aS5r0ZJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qdSE64Bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g9AUu1n7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d794r3qE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V3lvAbo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UC4v1thR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WYRjCX88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x0y05GiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KPAQfq7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T6R4mb4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MyTy8UPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sPjZ4urK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hF6x7Pnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OMpGAplu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_W34ABqyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_S3eQOCHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ARzcHtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O4HOYGRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NGU57nz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UEpDhG7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9YYYvpBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_idRnxbj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Fn576qfM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2fzcbhTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vhYP4T34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WPgvNL7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yLtTKDKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TXNKxxsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_1qClPNA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lunaZG9Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NJelFj86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GbyJWY7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rMOXCuun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HBz3RkAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R4udq7Ew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qD6Sn4or_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZZZLucn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zhdLqQUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_McTENH53_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VkZ8c8wO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dMnOfy30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DHv3qEnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FBtEkSa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zqtAKETY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YsQ9LjG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AduZBCFW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_pRrGVQnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_XE09p89c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m5AXFyuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HmDVlN8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PVLazNmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K4NHeTcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KJ05Yuq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tZF1jmLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_s7Yxg1vO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a1UoHEbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fUFXvlaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zBopBGoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zUlBAfs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_q88TBqLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qxIjd7XQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6UCy2FMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b4KeL9JC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NRwc7Wr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Bhjo8mn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y05mrQFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z8KwcLD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S7rgSv7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ttq0U8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E1fwUhR9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y0coYbx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GIMmIxwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IRNOSpHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iLtp3u9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p9ed4s6F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ValzBxag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HwCRFViA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RTnXbmAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uUlYflFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_om40u9mW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PRchTMss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P46rXIZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hRVi0twL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bi3bZcDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b9O07c7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GnJ3koTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJBV76bG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aE9dbXYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TqRlPlFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jG9queRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sZ28OB32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cU2T4K8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LbgFu5Br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y1nSwRIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VzR2tAHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T2znHfxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rynb0B3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bhV5hV5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TKkKzkAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SZCyUCCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h7PmOsq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cuQO1uJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYn3WLq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DviahPZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XCQekIRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lmGX2vOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_70QQes9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x7e1MLAC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ega3sWn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uqp8xIac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rb7XmLr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9AxhABM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_znezVLqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nk5jKiIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vEJrimg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xibJoGkN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fMns75k8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SBb9zEyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VhWx8tui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JbXqqW9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Onv7cpNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PMBeppMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HNvuszse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bbt8YKd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0gClNZBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UQChwJXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dwKOkMAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vAYRESi0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_5afmCjoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JnonAyLh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_siuNyk3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fYctclDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b7GrA6Zw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oN5GxLFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ic4j5qZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u8Ta7qDA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_8AmOYzRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zCoj9E7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hdZ0dubA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Rh9cJxD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_K47zZeV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_k9llOnsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_HNKgDQaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2J8j15Qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uz3PgfLY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rjnpq6V2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CF4x53hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X66uU5Zk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jT7bkXeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ToZvdUcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKu9KkCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H3u8eT1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nIK5Fd7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NieSwTh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a08Bbolk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hdJodci8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_BEsT172W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IjJM4V0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PTNcgO3k_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_arY2Wegz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m6cARmiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H2dhAsBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IhbrJlPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_puupe4C5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DQ18Zu3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iYPVceXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5jH0713d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AI8o1Kli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YaZCiBjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y4kRu06e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ykE8zKqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ProyR6Hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vl4Du1PH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_twPqxV7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mCHX5TNp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qjO4SiWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_flEy9TUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZklkjtKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2IGjtMut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LiioHxW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WXHBcvYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_63bY4m0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qb3bpTV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B6K6Y1al_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DfzZNqfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mL4eL7gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Wy9NDlBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZUntc9VP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DP8gvber_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sRrwJMGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AsGYfU5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iy1YaQZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aWPJNeyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z4hvjGE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ytXIinyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rXYrIowk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hm0bq0mm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rw3U18an_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N5lzR6wp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IBHa4cY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvcfVF5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yaebTX0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S3vaOZMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rbl4w04J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Quuq99dX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yD69kkt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LuFczSeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nfwHVAVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YAjV78EG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8isOiGlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vVZwB5iI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5KdZNSLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8gfR6Tlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BMlhHqpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UwgWMd7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IowUvDO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_co6RV58F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZvfQQpy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h85wTiFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_43aZAB8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qRoT3nSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_INr0eVWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dagxqsxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kwDMOKeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y5gX2pJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tCaLXnRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7SjxYYkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7fdk5NHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IdaC0iZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jKS5cziW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_49hsdzQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YEvWYeYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KELYWFzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8TAZoPA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VjIRdb6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G7lQOA7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vv8PnksE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QKq36wpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_i0N34WD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dzd4aAt7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lkpJ0FI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XJBLCl3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3UyH4f6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Nl0Ix7ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4VStEtPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nBMs12rR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dmCiEhRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lV6dMima_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yYFNFDOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_d88hy54u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_l43ru0xZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ARlxh7Li_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AV7kDxXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LUoJe0Dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZcLQ8oM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tezUb3nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_STIqfz7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DWYLUzoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z5sXHqBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_ccAFn6rs;
  SignalLine sLine_VbLGbSPu;
  SignalLine sLine_Qel0Tz3o;
  SignalTabhead sTabhead_grRbYKwb;
  SignalTabread sTabread_lcCbmPPB;
  SignalTabread sTabread_SZRleZot;
  SignalTabhead sTabhead_vEl8MDRo;
  SignalTabread sTabread_ATDpSllt;
  SignalTabread sTabread_sQ0SwIVa;
  SignalTabwrite sTabwrite_cHAnGjC6;
  SignalRPole sRPole_RfBeyYXJ;
  SignalDel1 sDel1_xMHOJWIx;
  SignalTabread sTabread_HNKgDQaO;
  SignalTabwrite sTabwrite_QulgOzMA;
  SignalTabread sTabread_CRiwZOJf;
  SignalRPole sRPole_V0Dobz9U;
  SignalLine sLine_YPcE17P9;
  SignalLine sLine_5c5dYBmu;
  SignalTabread sTabread_8oOCCrlF;
  SignalTabread sTabread_Etj4xFi4;
  SignalTabread sTabread_T6J56BhL;
  SignalTabread sTabread_MipP36Ox;
  SignalTabread sTabread_qxIjd7XQ;
  SignalTabread sTabread_1qClPNA1;
  SignalTabwrite sTabwrite_g5XdYfUv;
  SignalTabwrite sTabwrite_IAHxzDlc;
  SignalTabwrite sTabwrite_05mLGdNx;
  SignalTabwrite sTabwrite_sTAENXFQ;
  SignalTabwrite sTabwrite_NvJKi4cG;
  SignalTabwrite sTabwrite_mrvpLTk5;
  SignalTabread sTabread_wJUHA0Xm;
  SignalRPole sRPole_We8uyL7C;
  SignalTabread sTabread_H3Au2zq1;
  SignalRPole sRPole_gD8hzrb4;
  SignalTabread sTabread_OG6LvJkQ;
  SignalRPole sRPole_KQF0tYQO;
  SignalTabwrite sTabwrite_LMuAlumG;
  SignalTabwrite sTabwrite_pFoZgzbg;
  SignalTabwrite sTabwrite_NQlWomvF;
  SignalTabwrite sTabwrite_Qng1z6EL;
  SignalLine sLine_shf14V2b;
  ControlVar cVar_Yedrrxkn;
  ControlVar cVar_gZUGTgm6;
  ControlPack cPack_ProoUtgo;
  ControlBinop cBinop_k7dCR3ur;
  ControlVar cVar_IUhFTGy8;
  ControlPack cPack_F0r46CoR;
  ControlVar cVar_Fwb5ae2F;
  ControlVar cVar_0lEnlZE0;
  ControlDelay cDelay_Xb4BW88J;
  ControlDelay cDelay_kkHDjP8u;
  ControlBinop cBinop_26O5jsdo;
  HvTable hTable_24njKF1a;
  ControlBinop cBinop_shKCQfDD;
  ControlVar cVar_6T51SsZ3;
  ControlBinop cBinop_PBWWxa2q;
  ControlBinop cBinop_048U9e46;
  SignalVarf sVarf_vnMJTBPF;
  SignalVarf sVarf_JppLYqJG;
  SignalVarf sVarf_Xm2br7CB;
  ControlVar cVar_6tDQkw64;
  ControlBinop cBinop_2BP2oDJa;
  ControlBinop cBinop_cWpYC41b;
  SignalVarf sVarf_uf2chAfm;
  SignalVarf sVarf_ILpT1l4V;
  SignalVarf sVarf_URptrByN;
  ControlBinop cBinop_TSrpXIjd;
  ControlBinop cBinop_NWPNJkR4;
  ControlBinop cBinop_fa9oVkIv;
  ControlBinop cBinop_MoSASh9U;
  ControlBinop cBinop_JpDYt4Z3;
  ControlBinop cBinop_rflEmdDX;
  ControlBinop cBinop_KGKktrXI;
  ControlBinop cBinop_G4sj1UIY;
  ControlBinop cBinop_vv9gVl7M;
  SignalVarf sVarf_iuPD36f6;
  ControlVar cVar_3q0Jcyol;
  ControlBinop cBinop_Hh3uaHGB;
  ControlBinop cBinop_JFbfVUfo;
  ControlBinop cBinop_G8c9hrEr;
  ControlBinop cBinop_uHLJusX4;
  ControlBinop cBinop_HUdAPzfd;
  ControlBinop cBinop_tQCBkGXJ;
  ControlBinop cBinop_qnO6Bm3a;
  SignalVarf sVarf_nyeDoN5b;
  ControlBinop cBinop_9GVFdYr5;
  ControlRandom cRandom_v033bRGI;
  ControlSlice cSlice_gvIK9KGs;
  ControlDelay cDelay_E4nvqz4q;
  ControlVar cVar_IEVN1eYC;
  ControlBinop cBinop_Ofzd7vKb;
  ControlBinop cBinop_nuCJFK4U;
  ControlBinop cBinop_DOWS8B1x;
  ControlTabhead cTabhead_eflvBCvL;
  ControlVar cVar_AFI9dnfK;
  ControlDelay cDelay_TdTDAkDh;
  ControlDelay cDelay_ESq0zOdQ;
  ControlBinop cBinop_AOJnu09I;
  ControlBinop cBinop_DuTlKZTa;
  ControlBinop cBinop_4vNNu83H;
  ControlBinop cBinop_AO4zmk6r;
  ControlBinop cBinop_r6JwbzY1;
  ControlBinop cBinop_BlRB2qin;
  ControlTabhead cTabhead_we6Ffhmv;
  ControlVar cVar_62gc3yjW;
  ControlDelay cDelay_6l2SZDkY;
  ControlDelay cDelay_AsSnykBl;
  ControlBinop cBinop_wCaRy48M;
  ControlBinop cBinop_XEfPSm4F;
  ControlBinop cBinop_mR3M6NPI;
  ControlBinop cBinop_6kXR7fiM;
  ControlBinop cBinop_j6YHbu4C;
  ControlBinop cBinop_KHPwxFCM;
  ControlTabhead cTabhead_pYjuD1Jl;
  ControlVar cVar_s43ZImzf;
  ControlDelay cDelay_MN748Cqn;
  ControlDelay cDelay_B19PdBiI;
  ControlBinop cBinop_JSkp9Za7;
  ControlBinop cBinop_CdfcFzSf;
  ControlBinop cBinop_qlFoZrvU;
  ControlBinop cBinop_YOctYB71;
  ControlBinop cBinop_MYfhARHK;
  ControlBinop cBinop_bmkPs86X;
  ControlTabhead cTabhead_9cmRcgH4;
  ControlVar cVar_V8VzwWZs;
  ControlDelay cDelay_6eLESJEH;
  ControlDelay cDelay_568j2KzC;
  ControlBinop cBinop_xkgton2g;
  ControlBinop cBinop_A8y418CO;
  ControlBinop cBinop_TqOi6g3J;
  ControlBinop cBinop_NKYWKJBH;
  ControlBinop cBinop_XzqU1BZ4;
  ControlBinop cBinop_xms2rKwg;
  ControlDelay cDelay_ONEXBuKA;
  ControlDelay cDelay_9ZsBeMr1;
  ControlBinop cBinop_4APvdDQY;
  HvTable hTable_SPM6X5xU;
  ControlBinop cBinop_astcxfBO;
  ControlDelay cDelay_2V7O477o;
  ControlDelay cDelay_hAvMymTt;
  ControlBinop cBinop_YLrwOTH7;
  HvTable hTable_FFckGgqf;
  ControlBinop cBinop_revuQffC;
  ControlDelay cDelay_BH9TrJaF;
  ControlDelay cDelay_bxZ3lice;
  ControlBinop cBinop_70jGa3tE;
  HvTable hTable_UzNda0mb;
  ControlBinop cBinop_VTDYpyRr;
  ControlDelay cDelay_9SvPVVOc;
  ControlDelay cDelay_qV4DjCLR;
  ControlBinop cBinop_bymITcNH;
  HvTable hTable_WugpC00k;
  ControlBinop cBinop_zEirnjGa;
  ControlPack cPack_w5DLKjzJ;
  ControlPack cPack_X68bxY3p;
  ControlBinop cBinop_R3Vfejp6;
  ControlBinop cBinop_rCGsVz2I;
  ControlVar cVar_mLVPu7ku;
  ControlBinop cBinop_gQrik1Id;
  ControlBinop cBinop_Uj0glqiC;
  SignalVarf sVarf_ojOdSETX;
  ControlBinop cBinop_QbawmBWp;
  ControlBinop cBinop_LEfvNqvg;
  ControlBinop cBinop_WvWIhpG2;
  SignalVarf sVarf_cZyj9lcf;
  ControlVar cVar_H3wDlbzV;
  ControlVar cVar_l8j2KzQ9;
  ControlVar cVar_FJbdrw8s;
  ControlVar cVar_zdFYPJ2q;
  ControlIf cIf_85X5llo3;
  ControlBinop cBinop_6cM78XlF;
  ControlBinop cBinop_fK0HX5kI;
  ControlBinop cBinop_CFaC3mov;
  ControlDelay cDelay_SXJiR44u;
  ControlDelay cDelay_MjrxypN9;
  ControlBinop cBinop_NkyFL5G0;
  HvTable hTable_eINhsJT7;
  ControlBinop cBinop_IRc7HR5m;
  ControlTabhead cTabhead_t6XdP8hy;
  ControlVar cVar_uJ1HeKY7;
  ControlDelay cDelay_3fcikbIy;
  ControlDelay cDelay_UICYZ62b;
  ControlBinop cBinop_LHoeIwm8;
  ControlBinop cBinop_7nxN7tkF;
  ControlBinop cBinop_F6WuLR2W;
  ControlBinop cBinop_KhVIobJw;
  ControlBinop cBinop_AcfA55bP;
  ControlBinop cBinop_wfesOiGn;
  ControlDelay cDelay_H6FkY3i2;
  ControlDelay cDelay_PANENFLh;
  ControlBinop cBinop_yX84qXem;
  HvTable hTable_I8YNsA5g;
  ControlBinop cBinop_QGs8S2Y2;
  ControlTabhead cTabhead_81nqNms3;
  ControlVar cVar_smL22Bux;
  ControlDelay cDelay_6AX9AusA;
  ControlDelay cDelay_vQaCegpZ;
  ControlBinop cBinop_KHkkeRxx;
  ControlBinop cBinop_93NAYrqE;
  ControlBinop cBinop_F7fFx8gd;
  ControlBinop cBinop_HBF9oU5k;
  ControlBinop cBinop_4Ex78Xs9;
  ControlBinop cBinop_hbCc5OQA;
  ControlDelay cDelay_yfFJtGZq;
  ControlDelay cDelay_6hgJNb5k;
  ControlBinop cBinop_9pqlLOE1;
  HvTable hTable_nVqeN0aT;
  ControlBinop cBinop_yhdfXW5B;
  ControlTabhead cTabhead_UnUc8etL;
  ControlVar cVar_R2urZoI7;
  ControlDelay cDelay_VFPMjpeq;
  ControlDelay cDelay_L28301ei;
  ControlBinop cBinop_wmW00iAu;
  ControlBinop cBinop_o1rt35EO;
  ControlBinop cBinop_fSabaBDa;
  ControlBinop cBinop_W2nkemya;
  ControlBinop cBinop_Za5rj3zX;
  ControlBinop cBinop_Xw3yXoQh;
  ControlDelay cDelay_EaCE73qJ;
  ControlDelay cDelay_06PUTPOm;
  ControlBinop cBinop_aiXq7RAj;
  HvTable hTable_dsSyN1WZ;
  ControlBinop cBinop_LBXyUs2c;
  ControlTabhead cTabhead_4d3kI8dD;
  ControlVar cVar_DFw62a3j;
  ControlDelay cDelay_EsuSdWTp;
  ControlDelay cDelay_8OCxHb3h;
  ControlBinop cBinop_WOrt9548;
  ControlBinop cBinop_yXsYLydm;
  ControlBinop cBinop_qyP12NAY;
  ControlBinop cBinop_V3lvAbo4;
  ControlBinop cBinop_WYRjCX88;
  ControlBinop cBinop_x0y05GiE;
  ControlDelay cDelay_sPjZ4urK;
  ControlDelay cDelay_hF6x7Pnd;
  ControlBinop cBinop_W34ABqyN;
  HvTable hTable_S3eQOCHV;
  ControlBinop cBinop_O4HOYGRS;
  ControlTabhead cTabhead_Fn576qfM;
  ControlVar cVar_WPgvNL7F;
  ControlDelay cDelay_yLtTKDKz;
  ControlDelay cDelay_TXNKxxsx;
  ControlBinop cBinop_lunaZG9Q;
  ControlBinop cBinop_NJelFj86;
  ControlBinop cBinop_GbyJWY7v;
  ControlBinop cBinop_WZZZLucn;
  ControlBinop cBinop_McTENH53;
  ControlBinop cBinop_VkZ8c8wO;
  ControlDelay cDelay_zqtAKETY;
  ControlDelay cDelay_YsQ9LjG6;
  ControlBinop cBinop_pRrGVQnY;
  HvTable hTable_XE09p89c;
  ControlBinop cBinop_HmDVlN8x;
  ControlTabhead cTabhead_s7Yxg1vO;
  ControlVar cVar_zBopBGoD;
  ControlDelay cDelay_zUlBAfs9;
  ControlDelay cDelay_q88TBqLu;
  ControlBinop cBinop_6UCy2FMQ;
  ControlBinop cBinop_b4KeL9JC;
  ControlBinop cBinop_NRwc7Wr6;
  ControlBinop cBinop_3ttq0U8i;
  ControlBinop cBinop_y0coYbx6;
  ControlBinop cBinop_GIMmIxwz;
  ControlVar cVar_iLtp3u9Y;
  ControlVar cVar_p9ed4s6F;
  ControlPack cPack_ValzBxag;
  ControlVar cVar_HwCRFViA;
  ControlBinop cBinop_om40u9mW;
  ControlBinop cBinop_PRchTMss;
  SignalVarf sVarf_EGx8QEf1;
  ControlBinop cBinop_hRVi0twL;
  ControlBinop cBinop_Bi3bZcDh;
  ControlBinop cBinop_b9O07c7b;
  SignalVarf sVarf_CuNC0ETc;
  ControlVar cVar_GnJ3koTH;
  ControlBinop cBinop_TqRlPlFl;
  ControlBinop cBinop_jG9queRJ;
  SignalVarf sVarf_CaCtHWfh;
  ControlBinop cBinop_cU2T4K8B;
  ControlBinop cBinop_LbgFu5Br;
  ControlBinop cBinop_Y1nSwRIC;
  SignalVarf sVarf_5giHGhUr;
  ControlVar cVar_VzR2tAHU;
  ControlBinop cBinop_bhV5hV5L;
  ControlBinop cBinop_TKkKzkAq;
  SignalVarf sVarf_7BEeQR7m;
  ControlBinop cBinop_h7PmOsq0;
  ControlBinop cBinop_cuQO1uJT;
  ControlBinop cBinop_iYn3WLq6;
  SignalVarf sVarf_ZyPVMXzP;
  ControlBinop cBinop_DviahPZE;
  ControlBinop cBinop_lmGX2vOF;
  ControlBinop cBinop_70QQes9s;
  ControlDelay cDelay_ega3sWn7;
  ControlVar cVar_znezVLqr;
  ControlBinop cBinop_vEJrimg1;
  ControlBinop cBinop_xibJoGkN;
  ControlBinop cBinop_fMns75k8;
  ControlVar cVar_SBb9zEyH;
  ControlVar cVar_VhWx8tui;
  ControlIf cIf_PMBeppMd;
  ControlBinop cBinop_HNvuszse;
  ControlDelay cDelay_UQChwJXO;
  ControlDelay cDelay_dwKOkMAx;
  ControlBinop cBinop_5afmCjoi;
  HvTable hTable_JnonAyLh;
  ControlBinop cBinop_fYctclDV;
  ControlTabhead cTabhead_8AmOYzRE;
  ControlVar cVar_Rh9cJxD5;
  ControlDelay cDelay_K47zZeV6;
  ControlDelay cDelay_k9llOnsa;
  ControlBinop cBinop_2J8j15Qm;
  ControlBinop cBinop_Uz3PgfLY;
  ControlBinop cBinop_rjnpq6V2;
  ControlBinop cBinop_kKu9KkCs;
  ControlBinop cBinop_nIK5Fd7n;
  ControlBinop cBinop_NieSwTh6;
  ControlVar cVar_IjJM4V0y;
  ControlVar cVar_m6cARmiy;
  ControlVar cVar_H2dhAsBT;
  ControlVar cVar_IhbrJlPw;
  ControlVar cVar_puupe4C5;
  ControlVar cVar_DQ18Zu3N;
  ControlIf cIf_AI8o1Kli;
  ControlBinop cBinop_YaZCiBjL;
  ControlVar cVar_y4kRu06e;
  ControlIf cIf_vl4Du1PH;
  ControlBinop cBinop_twPqxV7C;
  ControlSlice cSlice_qjO4SiWM;
  ControlSlice cSlice_flEy9TUP;
  ControlVar cVar_ZklkjtKR;
  ControlIf cIf_2IGjtMut;
  ControlBinop cBinop_63bY4m0g;
  ControlIf cIf_DfzZNqfc;
  ControlIf cIf_mL4eL7gp;
  ControlIf cIf_Wy9NDlBD;
  ControlIf cIf_ZUntc9VP;
  ControlIf cIf_DP8gvber;
  SignalVarf sVarf_dBR2eu8q;
  ControlBinop cBinop_Z4hvjGE6;
  ControlBinop cBinop_ytXIinyS;
  ControlBinop cBinop_hm0bq0mm;
  ControlBinop cBinop_rw3U18an;
  SignalVarf sVarf_wtYgI2PL;
  ControlBinop cBinop_IBHa4cY5;
  ControlBinop cBinop_TvcfVF5j;
  SignalVarf sVarf_Sor1q6Ay;
  SignalVarf sVarf_NP36LcID;
  ControlBinop cBinop_yD69kkt1;
  ControlBinop cBinop_LuFczSeC;
  ControlBinop cBinop_nfwHVAVg;
  ControlBinop cBinop_YAjV78EG;
  ControlBinop cBinop_vVZwB5iI;
  ControlBinop cBinop_5KdZNSLK;
  ControlBinop cBinop_8gfR6Tlj;
  ControlBinop cBinop_BMlhHqpV;
  ControlBinop cBinop_IowUvDO0;
  ControlBinop cBinop_co6RV58F;
  ControlBinop cBinop_ZvfQQpy5;
  ControlBinop cBinop_IdaC0iZk;
  ControlBinop cBinop_jKS5cziW;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
