/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_ccAFn6rs, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_VbLGbSPu);
  numBytes += sLine_init(&sLine_Qel0Tz3o);
  numBytes += sTabhead_init(&sTabhead_grRbYKwb, &hTable_24njKF1a);
  numBytes += sTabread_init(&sTabread_lcCbmPPB, &hTable_24njKF1a, false);
  numBytes += sTabread_init(&sTabread_SZRleZot, &hTable_24njKF1a, false);
  numBytes += sTabhead_init(&sTabhead_vEl8MDRo, &hTable_24njKF1a);
  numBytes += sTabread_init(&sTabread_ATDpSllt, &hTable_24njKF1a, false);
  numBytes += sTabread_init(&sTabread_sQ0SwIVa, &hTable_24njKF1a, false);
  numBytes += sTabwrite_init(&sTabwrite_cHAnGjC6, &hTable_24njKF1a);
  numBytes += sRPole_init(&sRPole_RfBeyYXJ);
  numBytes += sDel1_init(&sDel1_xMHOJWIx);
  numBytes += sTabread_init(&sTabread_HNKgDQaO, &hTable_JnonAyLh, true);
  numBytes += sTabwrite_init(&sTabwrite_QulgOzMA, &hTable_JnonAyLh);
  numBytes += sTabread_init(&sTabread_CRiwZOJf, &hTable_SPM6X5xU, true);
  numBytes += sRPole_init(&sRPole_V0Dobz9U);
  numBytes += sLine_init(&sLine_YPcE17P9);
  numBytes += sLine_init(&sLine_5c5dYBmu);
  numBytes += sTabread_init(&sTabread_8oOCCrlF, &hTable_eINhsJT7, true);
  numBytes += sTabread_init(&sTabread_Etj4xFi4, &hTable_I8YNsA5g, true);
  numBytes += sTabread_init(&sTabread_T6J56BhL, &hTable_nVqeN0aT, true);
  numBytes += sTabread_init(&sTabread_MipP36Ox, &hTable_dsSyN1WZ, true);
  numBytes += sTabread_init(&sTabread_qxIjd7XQ, &hTable_XE09p89c, true);
  numBytes += sTabread_init(&sTabread_1qClPNA1, &hTable_S3eQOCHV, true);
  numBytes += sTabwrite_init(&sTabwrite_g5XdYfUv, &hTable_eINhsJT7);
  numBytes += sTabwrite_init(&sTabwrite_IAHxzDlc, &hTable_I8YNsA5g);
  numBytes += sTabwrite_init(&sTabwrite_05mLGdNx, &hTable_nVqeN0aT);
  numBytes += sTabwrite_init(&sTabwrite_sTAENXFQ, &hTable_dsSyN1WZ);
  numBytes += sTabwrite_init(&sTabwrite_NvJKi4cG, &hTable_S3eQOCHV);
  numBytes += sTabwrite_init(&sTabwrite_mrvpLTk5, &hTable_XE09p89c);
  numBytes += sTabread_init(&sTabread_wJUHA0Xm, &hTable_FFckGgqf, true);
  numBytes += sRPole_init(&sRPole_We8uyL7C);
  numBytes += sTabread_init(&sTabread_H3Au2zq1, &hTable_UzNda0mb, true);
  numBytes += sRPole_init(&sRPole_gD8hzrb4);
  numBytes += sTabread_init(&sTabread_OG6LvJkQ, &hTable_WugpC00k, true);
  numBytes += sRPole_init(&sRPole_KQF0tYQO);
  numBytes += sTabwrite_init(&sTabwrite_LMuAlumG, &hTable_SPM6X5xU);
  numBytes += sTabwrite_init(&sTabwrite_pFoZgzbg, &hTable_FFckGgqf);
  numBytes += sTabwrite_init(&sTabwrite_NQlWomvF, &hTable_UzNda0mb);
  numBytes += sTabwrite_init(&sTabwrite_Qng1z6EL, &hTable_WugpC00k);
  numBytes += sLine_init(&sLine_shf14V2b);
  numBytes += cVar_init_f(&cVar_Yedrrxkn, 0.0f);
  numBytes += cVar_init_f(&cVar_gZUGTgm6, 0.0f);
  numBytes += cPack_init(&cPack_ProoUtgo, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_IUhFTGy8, 0.0f);
  numBytes += cPack_init(&cPack_F0r46CoR, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_Fwb5ae2F, 0.0f);
  numBytes += cVar_init_f(&cVar_0lEnlZE0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Xb4BW88J, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kkHDjP8u, 0.0f);
  numBytes += hTable_init(&hTable_24njKF1a, 256);
  numBytes += cVar_init_s(&cVar_6T51SsZ3, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_vnMJTBPF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JppLYqJG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xm2br7CB, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_6tDQkw64, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_uf2chAfm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ILpT1l4V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_URptrByN, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_TSrpXIjd, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_iuPD36f6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3q0Jcyol, 0.0f);
  numBytes += cBinop_init(&cBinop_qnO6Bm3a, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_nyeDoN5b, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_v033bRGI, -1834487303);
  numBytes += cSlice_init(&cSlice_gvIK9KGs, 1, 1);
  numBytes += cDelay_init(this, &cDelay_E4nvqz4q, 0.0f);
  numBytes += cVar_init_f(&cVar_IEVN1eYC, 5.0f);
  numBytes += cBinop_init(&cBinop_DOWS8B1x, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_eflvBCvL, &hTable_SPM6X5xU);
  numBytes += cVar_init_s(&cVar_AFI9dnfK, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_TdTDAkDh, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_ESq0zOdQ, 0.0f);
  numBytes += cBinop_init(&cBinop_AOJnu09I, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_4vNNu83H, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_AO4zmk6r, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_BlRB2qin, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_we6Ffhmv, &hTable_FFckGgqf);
  numBytes += cVar_init_s(&cVar_62gc3yjW, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_6l2SZDkY, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_AsSnykBl, 0.0f);
  numBytes += cBinop_init(&cBinop_wCaRy48M, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_mR3M6NPI, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6kXR7fiM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_KHPwxFCM, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_pYjuD1Jl, &hTable_UzNda0mb);
  numBytes += cVar_init_s(&cVar_s43ZImzf, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_MN748Cqn, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_B19PdBiI, 0.0f);
  numBytes += cBinop_init(&cBinop_JSkp9Za7, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_qlFoZrvU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YOctYB71, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bmkPs86X, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_9cmRcgH4, &hTable_WugpC00k);
  numBytes += cVar_init_s(&cVar_V8VzwWZs, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_6eLESJEH, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_568j2KzC, 0.0f);
  numBytes += cBinop_init(&cBinop_xkgton2g, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_TqOi6g3J, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NKYWKJBH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_xms2rKwg, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ONEXBuKA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9ZsBeMr1, 0.0f);
  numBytes += hTable_init(&hTable_SPM6X5xU, 256);
  numBytes += cDelay_init(this, &cDelay_2V7O477o, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hAvMymTt, 0.0f);
  numBytes += hTable_init(&hTable_FFckGgqf, 256);
  numBytes += cDelay_init(this, &cDelay_BH9TrJaF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bxZ3lice, 0.0f);
  numBytes += hTable_init(&hTable_UzNda0mb, 256);
  numBytes += cDelay_init(this, &cDelay_9SvPVVOc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qV4DjCLR, 0.0f);
  numBytes += hTable_init(&hTable_WugpC00k, 256);
  numBytes += cPack_init(&cPack_w5DLKjzJ, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_X68bxY3p, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_mLVPu7ku, 22050.0f);
  numBytes += cBinop_init(&cBinop_gQrik1Id, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ojOdSETX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cZyj9lcf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H3wDlbzV, 0.0f);
  numBytes += cVar_init_f(&cVar_l8j2KzQ9, 0.0f);
  numBytes += cVar_init_f(&cVar_FJbdrw8s, 0.0f);
  numBytes += cVar_init_f(&cVar_zdFYPJ2q, 0.0f);
  numBytes += cIf_init(&cIf_85X5llo3, false);
  numBytes += cDelay_init(this, &cDelay_SXJiR44u, 0.0f);
  numBytes += cDelay_init(this, &cDelay_MjrxypN9, 0.0f);
  numBytes += hTable_init(&hTable_eINhsJT7, 256);
  numBytes += cTabhead_init(&cTabhead_t6XdP8hy, &hTable_eINhsJT7);
  numBytes += cVar_init_s(&cVar_uJ1HeKY7, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_3fcikbIy, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_UICYZ62b, 0.0f);
  numBytes += cBinop_init(&cBinop_LHoeIwm8, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_F6WuLR2W, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_KhVIobJw, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_wfesOiGn, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_H6FkY3i2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PANENFLh, 0.0f);
  numBytes += hTable_init(&hTable_I8YNsA5g, 256);
  numBytes += cTabhead_init(&cTabhead_81nqNms3, &hTable_I8YNsA5g);
  numBytes += cVar_init_s(&cVar_smL22Bux, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_6AX9AusA, 25.796f);
  numBytes += cDelay_init(this, &cDelay_vQaCegpZ, 0.0f);
  numBytes += cBinop_init(&cBinop_KHkkeRxx, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_F7fFx8gd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_HBF9oU5k, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hbCc5OQA, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_yfFJtGZq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6hgJNb5k, 0.0f);
  numBytes += hTable_init(&hTable_nVqeN0aT, 256);
  numBytes += cTabhead_init(&cTabhead_UnUc8etL, &hTable_nVqeN0aT);
  numBytes += cVar_init_s(&cVar_R2urZoI7, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_VFPMjpeq, 19.392f);
  numBytes += cDelay_init(this, &cDelay_L28301ei, 0.0f);
  numBytes += cBinop_init(&cBinop_wmW00iAu, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_fSabaBDa, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_W2nkemya, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Xw3yXoQh, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_EaCE73qJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_06PUTPOm, 0.0f);
  numBytes += hTable_init(&hTable_dsSyN1WZ, 256);
  numBytes += cTabhead_init(&cTabhead_4d3kI8dD, &hTable_dsSyN1WZ);
  numBytes += cVar_init_s(&cVar_DFw62a3j, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_EsuSdWTp, 16.364f);
  numBytes += cDelay_init(this, &cDelay_8OCxHb3h, 0.0f);
  numBytes += cBinop_init(&cBinop_WOrt9548, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_qyP12NAY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_V3lvAbo4, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_x0y05GiE, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_sPjZ4urK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hF6x7Pnd, 0.0f);
  numBytes += hTable_init(&hTable_S3eQOCHV, 256);
  numBytes += cTabhead_init(&cTabhead_Fn576qfM, &hTable_S3eQOCHV);
  numBytes += cVar_init_s(&cVar_WPgvNL7F, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_yLtTKDKz, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_TXNKxxsx, 0.0f);
  numBytes += cBinop_init(&cBinop_lunaZG9Q, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_GbyJWY7v, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WZZZLucn, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_VkZ8c8wO, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_zqtAKETY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_YsQ9LjG6, 0.0f);
  numBytes += hTable_init(&hTable_XE09p89c, 256);
  numBytes += cTabhead_init(&cTabhead_s7Yxg1vO, &hTable_XE09p89c);
  numBytes += cVar_init_s(&cVar_zBopBGoD, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_zUlBAfs9, 7.645f);
  numBytes += cDelay_init(this, &cDelay_q88TBqLu, 0.0f);
  numBytes += cBinop_init(&cBinop_6UCy2FMQ, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_NRwc7Wr6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3ttq0U8i, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GIMmIxwz, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_iLtp3u9Y, 0.0f);
  numBytes += cVar_init_f(&cVar_p9ed4s6F, 0.0f);
  numBytes += cPack_init(&cPack_ValzBxag, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_HwCRFViA, 22050.0f);
  numBytes += cBinop_init(&cBinop_om40u9mW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EGx8QEf1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CuNC0ETc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GnJ3koTH, 22050.0f);
  numBytes += cBinop_init(&cBinop_TqRlPlFl, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CaCtHWfh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5giHGhUr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VzR2tAHU, 22050.0f);
  numBytes += cBinop_init(&cBinop_bhV5hV5L, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7BEeQR7m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZyPVMXzP, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ega3sWn7, 0.0f);
  numBytes += cVar_init_f(&cVar_znezVLqr, 1000.0f);
  numBytes += cBinop_init(&cBinop_fMns75k8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SBb9zEyH, 0.0f);
  numBytes += cVar_init_f(&cVar_VhWx8tui, 0.0f);
  numBytes += cIf_init(&cIf_PMBeppMd, false);
  numBytes += cDelay_init(this, &cDelay_UQChwJXO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dwKOkMAx, 0.0f);
  numBytes += hTable_init(&hTable_JnonAyLh, 256);
  numBytes += cTabhead_init(&cTabhead_8AmOYzRE, &hTable_JnonAyLh);
  numBytes += cVar_init_s(&cVar_Rh9cJxD5, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_K47zZeV6, 150.0f);
  numBytes += cDelay_init(this, &cDelay_k9llOnsa, 0.0f);
  numBytes += cBinop_init(&cBinop_2J8j15Qm, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_rjnpq6V2, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kKu9KkCs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_NieSwTh6, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_IjJM4V0y, 0.0f);
  numBytes += cVar_init_f(&cVar_m6cARmiy, 0.0f);
  numBytes += cVar_init_f(&cVar_H2dhAsBT, 0.0f);
  numBytes += cVar_init_f(&cVar_IhbrJlPw, 0.0f);
  numBytes += cVar_init_f(&cVar_puupe4C5, 0.0f);
  numBytes += cVar_init_f(&cVar_DQ18Zu3N, 0.0f);
  numBytes += cIf_init(&cIf_AI8o1Kli, false);
  numBytes += cVar_init_f(&cVar_y4kRu06e, 0.0f);
  numBytes += cIf_init(&cIf_vl4Du1PH, false);
  numBytes += cSlice_init(&cSlice_qjO4SiWM, 1, -1);
  numBytes += cSlice_init(&cSlice_flEy9TUP, 1, -1);
  numBytes += cVar_init_f(&cVar_ZklkjtKR, 0.0f);
  numBytes += cIf_init(&cIf_2IGjtMut, false);
  numBytes += cBinop_init(&cBinop_63bY4m0g, 0.0f); // __neq
  numBytes += cIf_init(&cIf_DfzZNqfc, false);
  numBytes += cIf_init(&cIf_mL4eL7gp, false);
  numBytes += cIf_init(&cIf_Wy9NDlBD, false);
  numBytes += cIf_init(&cIf_ZUntc9VP, true);
  numBytes += cIf_init(&cIf_DP8gvber, false);
  numBytes += sVarf_init(&sVarf_dBR2eu8q, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_hm0bq0mm, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_wtYgI2PL, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_IBHa4cY5, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TvcfVF5j, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_Sor1q6Ay, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NP36LcID, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_LuFczSeC, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_IowUvDO0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_co6RV58F, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZvfQQpy5, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IdaC0iZk, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_jKS5cziW, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_ProoUtgo);
  cPack_free(&cPack_F0r46CoR);
  hTable_free(&hTable_24njKF1a);
  hTable_free(&hTable_SPM6X5xU);
  hTable_free(&hTable_FFckGgqf);
  hTable_free(&hTable_UzNda0mb);
  hTable_free(&hTable_WugpC00k);
  cPack_free(&cPack_w5DLKjzJ);
  cPack_free(&cPack_X68bxY3p);
  hTable_free(&hTable_eINhsJT7);
  hTable_free(&hTable_I8YNsA5g);
  hTable_free(&hTable_nVqeN0aT);
  hTable_free(&hTable_dsSyN1WZ);
  hTable_free(&hTable_S3eQOCHV);
  hTable_free(&hTable_XE09p89c);
  cPack_free(&cPack_ValzBxag);
  hTable_free(&hTable_JnonAyLh);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_24njKF1a; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_SPM6X5xU; // del-1052-del1
    case 0xA2AC524D: return &hTable_FFckGgqf; // del-1052-del2
    case 0xE36A35B: return &hTable_UzNda0mb; // del-1052-del3
    case 0x48CE0509: return &hTable_WugpC00k; // del-1052-del4
    case 0xE34D6E72: return &hTable_eINhsJT7; // del-1052-ref1
    case 0x6A1027AB: return &hTable_I8YNsA5g; // del-1052-ref2
    case 0xA37C6D49: return &hTable_nVqeN0aT; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_dsSyN1WZ; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_S3eQOCHV; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_XE09p89c; // del-1052-ref5
    case 0xED65564F: return &hTable_JnonAyLh; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vv8PnksE_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dzd4aAt7_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i0N34WD2_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z5sXHqBu_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QKq36wpd_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lkpJ0FI6_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XJBLCl3y_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nBMs12rR_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4VStEtPe_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dmCiEhRL_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lV6dMima_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3UyH4f6J_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nl0Ix7ul_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tezUb3nR_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZcLQ8oM5_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LUoJe0Dk_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AV7kDxXe_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DWYLUzoz_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_STIqfz7q_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d88hy54u_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yYFNFDOo_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ARlxh7Li_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l43ru0xZ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G7lQOA7l_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_Yedrrxkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_MoSASh9U_sendMessage);
}

void Heavy_ChaffVerb::cVar_gZUGTgm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_KGKktrXI_sendMessage);
}

void Heavy_ChaffVerb::cPack_ProoUtgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_VbLGbSPu, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_JNd2fTIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IUhFTGy8, 0, m, &cVar_IUhFTGy8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k7dCR3ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_JNd2fTIs_sendMessage);
}

void Heavy_ChaffVerb::cVar_IUhFTGy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fa9oVkIv_sendMessage);
}

void Heavy_ChaffVerb::cPack_F0r46CoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_Qel0Tz3o, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_Fwb5ae2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_rflEmdDX_sendMessage);
}

void Heavy_ChaffVerb::cVar_0lEnlZE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ccAFn6rs, 0, m);
}

void Heavy_ChaffVerb::cMsg_JnOPKHnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S9ONFFOF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_S9ONFFOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_shKCQfDD_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Xb4BW88J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xb4BW88J, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kkHDjP8u, 0, m, &cDelay_kkHDjP8u_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb4BW88J, 0, m, &cDelay_Xb4BW88J_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cHAnGjC6, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kkHDjP8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kkHDjP8u, m);
  cMsg_vIfFd1s4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ur0KaIOa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KsOLbx7K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_26O5jsdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yXe8bwmR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_24njKF1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M1kdMhwk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb4BW88J, 2, m, &cDelay_Xb4BW88J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mGendXed_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yXe8bwmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_24njKF1a, 0, m, &hTable_24njKF1a_sendMessage);
}

void Heavy_ChaffVerb::cBinop_shKCQfDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_26O5jsdo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vIfFd1s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_24njKF1a, 0, m, &hTable_24njKF1a_sendMessage);
}

void Heavy_ChaffVerb::cCast_mGendXed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb4BW88J, 0, m, &cDelay_Xb4BW88J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_M1kdMhwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kkHDjP8u, 2, m, &cDelay_kkHDjP8u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KsOLbx7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cHAnGjC6, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_z29I73fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h1CF8Cpq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_h1CF8Cpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PBWWxa2q_sendMessage);
}

void Heavy_ChaffVerb::cVar_6T51SsZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X5bXbPgm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_1b6EwfW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_048U9e46_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vnMJTBPF, m);
}

void Heavy_ChaffVerb::cBinop_PBWWxa2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JppLYqJG, m);
}

void Heavy_ChaffVerb::cMsg_X5bXbPgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1b6EwfW0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_048U9e46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xm2br7CB, m);
}

void Heavy_ChaffVerb::cMsg_1jYYRNr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7oxPg944_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7oxPg944_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2BP2oDJa_sendMessage);
}

void Heavy_ChaffVerb::cVar_6tDQkw64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X6WOiSgq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_Gnpod2FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cWpYC41b_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uf2chAfm, m);
}

void Heavy_ChaffVerb::cBinop_2BP2oDJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ILpT1l4V, m);
}

void Heavy_ChaffVerb::cMsg_X6WOiSgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Gnpod2FX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cWpYC41b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_URptrByN, m);
}

void Heavy_ChaffVerb::cBinop_TSrpXIjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0lEnlZE0, 0, m, &cVar_0lEnlZE0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NWPNJkR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Pk0tFbS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aiTRoOhz_sendMessage);
}

void Heavy_ChaffVerb::cCast_7Pk0tFbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSrpXIjd, HV_BINOP_DIVIDE, 1, m, &cBinop_TSrpXIjd_sendMessage);
}

void Heavy_ChaffVerb::cCast_aiTRoOhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSrpXIjd, HV_BINOP_DIVIDE, 0, m, &cBinop_TSrpXIjd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fa9oVkIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JpDYt4Z3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MoSASh9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_k7dCR3ur_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JpDYt4Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSrpXIjd, HV_BINOP_DIVIDE, 0, m, &cBinop_TSrpXIjd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rflEmdDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F0r46CoR, 0, m, &cPack_F0r46CoR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KGKktrXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_NWPNJkR4_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_ProoUtgo, 0, m, &cPack_ProoUtgo_sendMessage);
}

void Heavy_ChaffVerb::cUnop_fZXOetaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mL4eL7gp, 0, m, &cIf_mL4eL7gp_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_4PVtYCbu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UwJ1aWu1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0OxoIgYh_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uxT8Lbbg_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_UwJ1aWu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iy1YaQZ7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_0OxoIgYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AsGYfU5q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_uxT8Lbbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N5lzR6wp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_G4sj1UIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vv9gVl7M_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vv9gVl7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Hh3uaHGB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uHLJusX4_sendMessage);
}

void Heavy_ChaffVerb::cVar_3q0Jcyol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_HUdAPzfd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SXpljoXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ssfaH7az_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ssfaH7az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnO6Bm3a, HV_BINOP_DIVIDE, 1, m, &cBinop_qnO6Bm3a_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Hh3uaHGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JFbfVUfo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JFbfVUfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nyeDoN5b, m);
}

void Heavy_ChaffVerb::cMsg_5iuNdZeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_G8c9hrEr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G8c9hrEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_G4sj1UIY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uHLJusX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iuPD36f6, m);
}

void Heavy_ChaffVerb::cBinop_HUdAPzfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_tQCBkGXJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tQCBkGXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnO6Bm3a, HV_BINOP_DIVIDE, 0, m, &cBinop_qnO6Bm3a_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qnO6Bm3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iuNdZeA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Ew1cUWot_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gvIK9KGs, 0, m, &cSlice_gvIK9KGs_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_v033bRGI, 0, m, &cRandom_v033bRGI_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9GVFdYr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_aZ9GTpsC_sendMessage);
}

void Heavy_ChaffVerb::cUnop_aZ9GTpsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_ytXIinyS_sendMessage);
}

void Heavy_ChaffVerb::cRandom_v033bRGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_9GVFdYr5_sendMessage);
}

void Heavy_ChaffVerb::cSlice_gvIK9KGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_v033bRGI, 1, m, &cRandom_v033bRGI_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_qQJ9dGdI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_buiUPQ5E_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_buiUPQ5E_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HepXD9y9_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_E4nvqz4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E4nvqz4q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E4nvqz4q, 0, m, &cDelay_E4nvqz4q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SBb9zEyH, 0, m, &cVar_SBb9zEyH_sendMessage);
}

void Heavy_ChaffVerb::cCast_HepXD9y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_buiUPQ5E_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E4nvqz4q, 0, m, &cDelay_E4nvqz4q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SBb9zEyH, 0, m, &cVar_SBb9zEyH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oX1EbAmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qn0nhEVY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qn0nhEVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nuCJFK4U_sendMessage);
}

void Heavy_ChaffVerb::cVar_IEVN1eYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DOWS8B1x, HV_BINOP_MULTIPLY, 0, m, &cBinop_DOWS8B1x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_buiUPQ5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_E4nvqz4q, 0, m, &cDelay_E4nvqz4q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ofzd7vKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E4nvqz4q, 2, m, &cDelay_E4nvqz4q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nuCJFK4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DOWS8B1x, HV_BINOP_MULTIPLY, 1, m, &cBinop_DOWS8B1x_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DOWS8B1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Ofzd7vKb_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_eflvBCvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4vNNu83H, HV_BINOP_SUBTRACT, 0, m, &cBinop_4vNNu83H_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OVU8L592_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xEucgYjR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xEucgYjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DuTlKZTa_sendMessage);
}

void Heavy_ChaffVerb::cVar_AFI9dnfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RPHHK0Vv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_TdTDAkDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TdTDAkDh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESq0zOdQ, 0, m, &cDelay_ESq0zOdQ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CRiwZOJf, 0, m, &sTabread_CRiwZOJf_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ESq0zOdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ESq0zOdQ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CRiwZOJf, 0, m, &sTabread_CRiwZOJf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESq0zOdQ, 0, m, &cDelay_ESq0zOdQ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_CRiwZOJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_BlRB2qin, HV_BINOP_SUBTRACT, 0, m, &cBinop_BlRB2qin_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_AOJnu09I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AO4zmk6r, HV_BINOP_MAX, 0, m, &cBinop_AO4zmk6r_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DuTlKZTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AOJnu09I, HV_BINOP_MULTIPLY, 0, m, &cBinop_AOJnu09I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4vNNu83H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5QMCizw3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CRiwZOJf, 0, m, &sTabread_CRiwZOJf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QbPXSofw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HA6HB1VL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BlRB2qin, HV_BINOP_SUBTRACT, 1, m, &cBinop_BlRB2qin_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESq0zOdQ, 2, m, &cDelay_ESq0zOdQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RPHHK0Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HA6HB1VL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5QMCizw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TdTDAkDh, 0, m, &cDelay_TdTDAkDh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESq0zOdQ, 0, m, &cDelay_ESq0zOdQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gOuf8H5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_AO4zmk6r, HV_BINOP_MAX, 1, m, &cBinop_AO4zmk6r_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AO4zmk6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4vNNu83H, HV_BINOP_SUBTRACT, 1, m, &cBinop_4vNNu83H_sendMessage);
}

void Heavy_ChaffVerb::cCast_QbPXSofw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TdTDAkDh, 0, m, &cDelay_TdTDAkDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_r6JwbzY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TdTDAkDh, 2, m, &cDelay_TdTDAkDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BlRB2qin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_r6JwbzY1_sendMessage);
}

void Heavy_ChaffVerb::cCast_jFXiQ9MY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AFI9dnfK, 0, m, &cVar_AFI9dnfK_sendMessage);
  cMsg_OVU8L592_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_eflvBCvL, 0, m, &cTabhead_eflvBCvL_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_we6Ffhmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mR3M6NPI, HV_BINOP_SUBTRACT, 0, m, &cBinop_mR3M6NPI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eBTx9u9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jUFAFqju_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jUFAFqju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XEfPSm4F_sendMessage);
}

void Heavy_ChaffVerb::cVar_62gc3yjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nt74d6V1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_6l2SZDkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6l2SZDkY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AsSnykBl, 0, m, &cDelay_AsSnykBl_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wJUHA0Xm, 0, m, &sTabread_wJUHA0Xm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AsSnykBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AsSnykBl, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wJUHA0Xm, 0, m, &sTabread_wJUHA0Xm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AsSnykBl, 0, m, &cDelay_AsSnykBl_sendMessage);
}

void Heavy_ChaffVerb::sTabread_wJUHA0Xm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_KHPwxFCM, HV_BINOP_SUBTRACT, 0, m, &cBinop_KHPwxFCM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wCaRy48M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kXR7fiM, HV_BINOP_MAX, 0, m, &cBinop_6kXR7fiM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XEfPSm4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wCaRy48M, HV_BINOP_MULTIPLY, 0, m, &cBinop_wCaRy48M_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mR3M6NPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MSnzYtxL_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wJUHA0Xm, 0, m, &sTabread_wJUHA0Xm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aI3tJv1i_sendMessage);
}

void Heavy_ChaffVerb::cSystem_93CBjlX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHPwxFCM, HV_BINOP_SUBTRACT, 1, m, &cBinop_KHPwxFCM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AsSnykBl, 2, m, &cDelay_AsSnykBl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Nt74d6V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_93CBjlX2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MSnzYtxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l2SZDkY, 0, m, &cDelay_6l2SZDkY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AsSnykBl, 0, m, &cDelay_AsSnykBl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wMduhJ4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kXR7fiM, HV_BINOP_MAX, 1, m, &cBinop_6kXR7fiM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6kXR7fiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mR3M6NPI, HV_BINOP_SUBTRACT, 1, m, &cBinop_mR3M6NPI_sendMessage);
}

void Heavy_ChaffVerb::cCast_aI3tJv1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l2SZDkY, 0, m, &cDelay_6l2SZDkY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j6YHbu4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l2SZDkY, 2, m, &cDelay_6l2SZDkY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KHPwxFCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j6YHbu4C_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZeT7TFUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_62gc3yjW, 0, m, &cVar_62gc3yjW_sendMessage);
  cMsg_eBTx9u9t_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_we6Ffhmv, 0, m, &cTabhead_we6Ffhmv_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_pYjuD1Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlFoZrvU, HV_BINOP_SUBTRACT, 0, m, &cBinop_qlFoZrvU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QGUwlcgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aoCO63iL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aoCO63iL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CdfcFzSf_sendMessage);
}

void Heavy_ChaffVerb::cVar_s43ZImzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TxDaIDUO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_MN748Cqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MN748Cqn, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B19PdBiI, 0, m, &cDelay_B19PdBiI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H3Au2zq1, 0, m, &sTabread_H3Au2zq1_sendMessage);
}

void Heavy_ChaffVerb::cDelay_B19PdBiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B19PdBiI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H3Au2zq1, 0, m, &sTabread_H3Au2zq1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B19PdBiI, 0, m, &cDelay_B19PdBiI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_H3Au2zq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bmkPs86X, HV_BINOP_SUBTRACT, 0, m, &cBinop_bmkPs86X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_JSkp9Za7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YOctYB71, HV_BINOP_MAX, 0, m, &cBinop_YOctYB71_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CdfcFzSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JSkp9Za7, HV_BINOP_MULTIPLY, 0, m, &cBinop_JSkp9Za7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qlFoZrvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c6bvOwwU_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H3Au2zq1, 0, m, &sTabread_H3Au2zq1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q21nJ7v0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yLZnLteg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmkPs86X, HV_BINOP_SUBTRACT, 1, m, &cBinop_bmkPs86X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B19PdBiI, 2, m, &cDelay_B19PdBiI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TxDaIDUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yLZnLteg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c6bvOwwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MN748Cqn, 0, m, &cDelay_MN748Cqn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B19PdBiI, 0, m, &cDelay_B19PdBiI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OQLogK9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YOctYB71, HV_BINOP_MAX, 1, m, &cBinop_YOctYB71_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YOctYB71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlFoZrvU, HV_BINOP_SUBTRACT, 1, m, &cBinop_qlFoZrvU_sendMessage);
}

void Heavy_ChaffVerb::cCast_q21nJ7v0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MN748Cqn, 0, m, &cDelay_MN748Cqn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MYfhARHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MN748Cqn, 2, m, &cDelay_MN748Cqn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bmkPs86X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MYfhARHK_sendMessage);
}

void Heavy_ChaffVerb::cCast_KzLWzBFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s43ZImzf, 0, m, &cVar_s43ZImzf_sendMessage);
  cMsg_QGUwlcgd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_pYjuD1Jl, 0, m, &cTabhead_pYjuD1Jl_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_9cmRcgH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TqOi6g3J, HV_BINOP_SUBTRACT, 0, m, &cBinop_TqOi6g3J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cigfwYdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TEwOnO7p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TEwOnO7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_A8y418CO_sendMessage);
}

void Heavy_ChaffVerb::cVar_V8VzwWZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e9ZPsS3n_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_6eLESJEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6eLESJEH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_568j2KzC, 0, m, &cDelay_568j2KzC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OG6LvJkQ, 0, m, &sTabread_OG6LvJkQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_568j2KzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_568j2KzC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OG6LvJkQ, 0, m, &sTabread_OG6LvJkQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_568j2KzC, 0, m, &cDelay_568j2KzC_sendMessage);
}

void Heavy_ChaffVerb::sTabread_OG6LvJkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xms2rKwg, HV_BINOP_SUBTRACT, 0, m, &cBinop_xms2rKwg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xkgton2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKYWKJBH, HV_BINOP_MAX, 0, m, &cBinop_NKYWKJBH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A8y418CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkgton2g, HV_BINOP_MULTIPLY, 0, m, &cBinop_xkgton2g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TqOi6g3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Glb3RIin_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OG6LvJkQ, 0, m, &sTabread_OG6LvJkQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4wRZpL9s_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VeYdl1av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xms2rKwg, HV_BINOP_SUBTRACT, 1, m, &cBinop_xms2rKwg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_568j2KzC, 2, m, &cDelay_568j2KzC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e9ZPsS3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VeYdl1av_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Glb3RIin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6eLESJEH, 0, m, &cDelay_6eLESJEH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_568j2KzC, 0, m, &cDelay_568j2KzC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6uOdyVRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKYWKJBH, HV_BINOP_MAX, 1, m, &cBinop_NKYWKJBH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NKYWKJBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TqOi6g3J, HV_BINOP_SUBTRACT, 1, m, &cBinop_TqOi6g3J_sendMessage);
}

void Heavy_ChaffVerb::cCast_4wRZpL9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6eLESJEH, 0, m, &cDelay_6eLESJEH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XzqU1BZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6eLESJEH, 2, m, &cDelay_6eLESJEH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xms2rKwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XzqU1BZ4_sendMessage);
}

void Heavy_ChaffVerb::cCast_EfIhHHdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V8VzwWZs, 0, m, &cVar_V8VzwWZs_sendMessage);
  cMsg_cigfwYdD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9cmRcgH4, 0, m, &cTabhead_9cmRcgH4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SW7t7wQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7ibS7czn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7ibS7czn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_astcxfBO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ONEXBuKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ONEXBuKA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9ZsBeMr1, 0, m, &cDelay_9ZsBeMr1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ONEXBuKA, 0, m, &cDelay_ONEXBuKA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LMuAlumG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9ZsBeMr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9ZsBeMr1, m);
  cMsg_tFHAEGae_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_anozbq3d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_24jLh7To_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_4APvdDQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tpdqackN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_SPM6X5xU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_So1TKFte_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ONEXBuKA, 2, m, &cDelay_ONEXBuKA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvHhvUMc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tpdqackN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SPM6X5xU, 0, m, &hTable_SPM6X5xU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_astcxfBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_4APvdDQY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tFHAEGae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SPM6X5xU, 0, m, &hTable_SPM6X5xU_sendMessage);
}

void Heavy_ChaffVerb::cCast_kvHhvUMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ONEXBuKA, 0, m, &cDelay_ONEXBuKA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_So1TKFte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9ZsBeMr1, 2, m, &cDelay_9ZsBeMr1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_24jLh7To_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LMuAlumG, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_V9pHsvuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qt4lKLuB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Qt4lKLuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_revuQffC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2V7O477o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2V7O477o, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hAvMymTt, 0, m, &cDelay_hAvMymTt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2V7O477o, 0, m, &cDelay_2V7O477o_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pFoZgzbg, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hAvMymTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hAvMymTt, m);
  cMsg_gmqSR3kf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_LtfjcJCX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_jsx9L667_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_YLrwOTH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7RaRvHAR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_FFckGgqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BwjKrXuP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2V7O477o, 2, m, &cDelay_2V7O477o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N9dfjg8C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7RaRvHAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FFckGgqf, 0, m, &hTable_FFckGgqf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_revuQffC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_YLrwOTH7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gmqSR3kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FFckGgqf, 0, m, &hTable_FFckGgqf_sendMessage);
}

void Heavy_ChaffVerb::cCast_N9dfjg8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2V7O477o, 0, m, &cDelay_2V7O477o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BwjKrXuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hAvMymTt, 2, m, &cDelay_hAvMymTt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jsx9L667_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pFoZgzbg, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_zOWeDKNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wPOmEV4F_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wPOmEV4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VTDYpyRr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_BH9TrJaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BH9TrJaF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bxZ3lice, 0, m, &cDelay_bxZ3lice_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BH9TrJaF, 0, m, &cDelay_BH9TrJaF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NQlWomvF, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bxZ3lice_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bxZ3lice, m);
  cMsg_odl1SLLs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_uQGvN0JO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_553ZOStN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_70jGa3tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X0QdYI64_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_UzNda0mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lvJ0vASf_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BH9TrJaF, 2, m, &cDelay_BH9TrJaF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qErT4d2k_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X0QdYI64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_UzNda0mb, 0, m, &hTable_UzNda0mb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VTDYpyRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_70jGa3tE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_odl1SLLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_UzNda0mb, 0, m, &hTable_UzNda0mb_sendMessage);
}

void Heavy_ChaffVerb::cCast_qErT4d2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BH9TrJaF, 0, m, &cDelay_BH9TrJaF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lvJ0vASf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bxZ3lice, 2, m, &cDelay_bxZ3lice_sendMessage);
}

void Heavy_ChaffVerb::cMsg_553ZOStN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NQlWomvF, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_U1vGPCXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w6n7BlAK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_w6n7BlAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zEirnjGa_sendMessage);
}

void Heavy_ChaffVerb::cDelay_9SvPVVOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9SvPVVOc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qV4DjCLR, 0, m, &cDelay_qV4DjCLR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9SvPVVOc, 0, m, &cDelay_9SvPVVOc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Qng1z6EL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_qV4DjCLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qV4DjCLR, m);
  cMsg_CUJCs5s1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_oFAynuqC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mhkv4y0R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_bymITcNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZ6Rij2U_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_WugpC00k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QbcOOVoA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9SvPVVOc, 2, m, &cDelay_9SvPVVOc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3CAAdzd5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MZ6Rij2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WugpC00k, 0, m, &hTable_WugpC00k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zEirnjGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_bymITcNH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CUJCs5s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WugpC00k, 0, m, &hTable_WugpC00k_sendMessage);
}

void Heavy_ChaffVerb::cCast_3CAAdzd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9SvPVVOc, 0, m, &cDelay_9SvPVVOc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QbcOOVoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qV4DjCLR, 2, m, &cDelay_qV4DjCLR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mhkv4y0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Qng1z6EL, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_w5DLKjzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_shf14V2b, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_X68bxY3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_5c5dYBmu, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_R3Vfejp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rCGsVz2I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rCGsVz2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_DviahPZE_sendMessage);
}

void Heavy_ChaffVerb::cVar_mLVPu7ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQrik1Id, HV_BINOP_MULTIPLY, 0, m, &cBinop_gQrik1Id_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fdQY7HYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U1VwRZQr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_U1VwRZQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qPR0sb7k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_gQrik1Id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QbawmBWp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Uj0glqiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQrik1Id, HV_BINOP_MULTIPLY, 1, m, &cBinop_gQrik1Id_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qPR0sb7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Uj0glqiC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QbawmBWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LEfvNqvg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LEfvNqvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WvWIhpG2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cZyj9lcf, m);
}

void Heavy_ChaffVerb::cBinop_WvWIhpG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ojOdSETX, m);
}

void Heavy_ChaffVerb::cVar_H3wDlbzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_70QQes9s_sendMessage);
}

void Heavy_ChaffVerb::cVar_l8j2KzQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_R3Vfejp6_sendMessage);
}

void Heavy_ChaffVerb::cVar_FJbdrw8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_6cM78XlF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_85X5llo3, 0, m, &cIf_85X5llo3_sendMessage);
}

void Heavy_ChaffVerb::cVar_zdFYPJ2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fK0HX5kI_sendMessage);
}

void Heavy_ChaffVerb::cIf_85X5llo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XCQekIRa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_iLtp3u9Y, 0, m, &cVar_iLtp3u9Y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_6cM78XlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_85X5llo3, 1, m, &cIf_85X5llo3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fK0HX5kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CFaC3mov_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CFaC3mov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p9ed4s6F, 0, m, &cVar_p9ed4s6F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UB2ZegSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i0uPTQvJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_i0uPTQvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IRc7HR5m_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SXJiR44u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SXJiR44u, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MjrxypN9, 0, m, &cDelay_MjrxypN9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXJiR44u, 0, m, &cDelay_SXJiR44u_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g5XdYfUv, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_MjrxypN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MjrxypN9, m);
  cMsg_kXhQ4PIW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Yhit9pKm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZKYlwZzL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_NkyFL5G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0pEE7lv7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_eINhsJT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nhoFWE29_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXJiR44u, 2, m, &cDelay_SXJiR44u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z72Bg5cB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0pEE7lv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_eINhsJT7, 0, m, &hTable_eINhsJT7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IRc7HR5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_NkyFL5G0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kXhQ4PIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_eINhsJT7, 0, m, &hTable_eINhsJT7_sendMessage);
}

void Heavy_ChaffVerb::cCast_Z72Bg5cB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXJiR44u, 0, m, &cDelay_SXJiR44u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nhoFWE29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_MjrxypN9, 2, m, &cDelay_MjrxypN9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZKYlwZzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g5XdYfUv, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_t6XdP8hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6WuLR2W, HV_BINOP_SUBTRACT, 0, m, &cBinop_F6WuLR2W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cmgcSoFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VCS96T8y_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VCS96T8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7nxN7tkF_sendMessage);
}

void Heavy_ChaffVerb::cVar_uJ1HeKY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yud9D33B_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3fcikbIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3fcikbIy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UICYZ62b, 0, m, &cDelay_UICYZ62b_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8oOCCrlF, 0, m, &sTabread_8oOCCrlF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_UICYZ62b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UICYZ62b, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8oOCCrlF, 0, m, &sTabread_8oOCCrlF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UICYZ62b, 0, m, &cDelay_UICYZ62b_sendMessage);
}

void Heavy_ChaffVerb::sTabread_8oOCCrlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wfesOiGn, HV_BINOP_SUBTRACT, 0, m, &cBinop_wfesOiGn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LHoeIwm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhVIobJw, HV_BINOP_MAX, 0, m, &cBinop_KhVIobJw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7nxN7tkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LHoeIwm8, HV_BINOP_MULTIPLY, 0, m, &cBinop_LHoeIwm8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F6WuLR2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7JTjqugy_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8oOCCrlF, 0, m, &sTabread_8oOCCrlF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1PkCUvyf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Cy0DYGL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wfesOiGn, HV_BINOP_SUBTRACT, 1, m, &cBinop_wfesOiGn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UICYZ62b, 2, m, &cDelay_UICYZ62b_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Yud9D33B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cy0DYGL2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7JTjqugy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fcikbIy, 0, m, &cDelay_3fcikbIy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UICYZ62b, 0, m, &cDelay_UICYZ62b_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fizLJ01M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhVIobJw, HV_BINOP_MAX, 1, m, &cBinop_KhVIobJw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KhVIobJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6WuLR2W, HV_BINOP_SUBTRACT, 1, m, &cBinop_F6WuLR2W_sendMessage);
}

void Heavy_ChaffVerb::cCast_1PkCUvyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fcikbIy, 0, m, &cDelay_3fcikbIy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AcfA55bP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3fcikbIy, 2, m, &cDelay_3fcikbIy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wfesOiGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_AcfA55bP_sendMessage);
}

void Heavy_ChaffVerb::cCast_sirUNAyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJ1HeKY7, 0, m, &cVar_uJ1HeKY7_sendMessage);
  cMsg_cmgcSoFq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_t6XdP8hy, 0, m, &cTabhead_t6XdP8hy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q47XnGeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KWp96wPX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KWp96wPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QGs8S2Y2_sendMessage);
}

void Heavy_ChaffVerb::cDelay_H6FkY3i2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_H6FkY3i2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PANENFLh, 0, m, &cDelay_PANENFLh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6FkY3i2, 0, m, &cDelay_H6FkY3i2_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IAHxzDlc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_PANENFLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PANENFLh, m);
  cMsg_moQjoxf4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_tr8Phvp5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OWuQcHAP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_yX84qXem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0r3mJZDK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_I8YNsA5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vl6RJwGz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6FkY3i2, 2, m, &cDelay_H6FkY3i2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aDteivfJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0r3mJZDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_I8YNsA5g, 0, m, &hTable_I8YNsA5g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QGs8S2Y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_yX84qXem_sendMessage);
}

void Heavy_ChaffVerb::cMsg_moQjoxf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_I8YNsA5g, 0, m, &hTable_I8YNsA5g_sendMessage);
}

void Heavy_ChaffVerb::cCast_aDteivfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6FkY3i2, 0, m, &cDelay_H6FkY3i2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Vl6RJwGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PANENFLh, 2, m, &cDelay_PANENFLh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OWuQcHAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IAHxzDlc, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_81nqNms3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7fFx8gd, HV_BINOP_SUBTRACT, 0, m, &cBinop_F7fFx8gd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iIybrJNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2XpqifKg_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2XpqifKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_93NAYrqE_sendMessage);
}

void Heavy_ChaffVerb::cVar_smL22Bux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xvC3nkM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_6AX9AusA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6AX9AusA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQaCegpZ, 0, m, &cDelay_vQaCegpZ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Etj4xFi4, 0, m, &sTabread_Etj4xFi4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_vQaCegpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vQaCegpZ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Etj4xFi4, 0, m, &sTabread_Etj4xFi4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQaCegpZ, 0, m, &cDelay_vQaCegpZ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Etj4xFi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hbCc5OQA, HV_BINOP_SUBTRACT, 0, m, &cBinop_hbCc5OQA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_KHkkeRxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HBF9oU5k, HV_BINOP_MAX, 0, m, &cBinop_HBF9oU5k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_93NAYrqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHkkeRxx, HV_BINOP_MULTIPLY, 0, m, &cBinop_KHkkeRxx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F7fFx8gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HbwNUE2R_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Etj4xFi4, 0, m, &sTabread_Etj4xFi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7obWn091_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BY1NfSz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hbCc5OQA, HV_BINOP_SUBTRACT, 1, m, &cBinop_hbCc5OQA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQaCegpZ, 2, m, &cDelay_vQaCegpZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0xvC3nkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BY1NfSz2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HbwNUE2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AX9AusA, 0, m, &cDelay_6AX9AusA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQaCegpZ, 0, m, &cDelay_vQaCegpZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WShJ9blQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_HBF9oU5k, HV_BINOP_MAX, 1, m, &cBinop_HBF9oU5k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HBF9oU5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7fFx8gd, HV_BINOP_SUBTRACT, 1, m, &cBinop_F7fFx8gd_sendMessage);
}

void Heavy_ChaffVerb::cCast_7obWn091_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AX9AusA, 0, m, &cDelay_6AX9AusA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4Ex78Xs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AX9AusA, 2, m, &cDelay_6AX9AusA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hbCc5OQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4Ex78Xs9_sendMessage);
}

void Heavy_ChaffVerb::cCast_1vojhamF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_smL22Bux, 0, m, &cVar_smL22Bux_sendMessage);
  cMsg_iIybrJNC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_81nqNms3, 0, m, &cTabhead_81nqNms3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VdZEjLNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yx8FrdSl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yx8FrdSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yhdfXW5B_sendMessage);
}

void Heavy_ChaffVerb::cDelay_yfFJtGZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yfFJtGZq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hgJNb5k, 0, m, &cDelay_6hgJNb5k_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfFJtGZq, 0, m, &cDelay_yfFJtGZq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_05mLGdNx, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_6hgJNb5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6hgJNb5k, m);
  cMsg_bSl8prbF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_s2c5Ys1e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_iRe3PT1o_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9pqlLOE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLgK7jWV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_nVqeN0aT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_itKaRhhX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfFJtGZq, 2, m, &cDelay_yfFJtGZq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZY1oYFdD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eLgK7jWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nVqeN0aT, 0, m, &hTable_nVqeN0aT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yhdfXW5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_9pqlLOE1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bSl8prbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nVqeN0aT, 0, m, &hTable_nVqeN0aT_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZY1oYFdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yfFJtGZq, 0, m, &cDelay_yfFJtGZq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_itKaRhhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_6hgJNb5k, 2, m, &cDelay_6hgJNb5k_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iRe3PT1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_05mLGdNx, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_UnUc8etL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fSabaBDa, HV_BINOP_SUBTRACT, 0, m, &cBinop_fSabaBDa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VVRhIFY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tUrCPhvr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tUrCPhvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_o1rt35EO_sendMessage);
}

void Heavy_ChaffVerb::cVar_R2urZoI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qJDrLvX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_VFPMjpeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VFPMjpeq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L28301ei, 0, m, &cDelay_L28301ei_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_T6J56BhL, 0, m, &sTabread_T6J56BhL_sendMessage);
}

void Heavy_ChaffVerb::cDelay_L28301ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L28301ei, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_T6J56BhL, 0, m, &sTabread_T6J56BhL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L28301ei, 0, m, &cDelay_L28301ei_sendMessage);
}

void Heavy_ChaffVerb::sTabread_T6J56BhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Xw3yXoQh, HV_BINOP_SUBTRACT, 0, m, &cBinop_Xw3yXoQh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wmW00iAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2nkemya, HV_BINOP_MAX, 0, m, &cBinop_W2nkemya_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o1rt35EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmW00iAu, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmW00iAu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fSabaBDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JDzL2xoN_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_T6J56BhL, 0, m, &sTabread_T6J56BhL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A8eOQbhQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Unfh4lUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xw3yXoQh, HV_BINOP_SUBTRACT, 1, m, &cBinop_Xw3yXoQh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L28301ei, 2, m, &cDelay_L28301ei_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2qJDrLvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Unfh4lUG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JDzL2xoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VFPMjpeq, 0, m, &cDelay_VFPMjpeq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L28301ei, 0, m, &cDelay_L28301ei_sendMessage);
}

void Heavy_ChaffVerb::cMsg_40WSJGej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2nkemya, HV_BINOP_MAX, 1, m, &cBinop_W2nkemya_sendMessage);
}

void Heavy_ChaffVerb::cBinop_W2nkemya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fSabaBDa, HV_BINOP_SUBTRACT, 1, m, &cBinop_fSabaBDa_sendMessage);
}

void Heavy_ChaffVerb::cCast_A8eOQbhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VFPMjpeq, 0, m, &cDelay_VFPMjpeq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Za5rj3zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VFPMjpeq, 2, m, &cDelay_VFPMjpeq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Xw3yXoQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Za5rj3zX_sendMessage);
}

void Heavy_ChaffVerb::cCast_Czgebpwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R2urZoI7, 0, m, &cVar_R2urZoI7_sendMessage);
  cMsg_VVRhIFY4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UnUc8etL, 0, m, &cTabhead_UnUc8etL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MIFdkZeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4pAm1psI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4pAm1psI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LBXyUs2c_sendMessage);
}

void Heavy_ChaffVerb::cDelay_EaCE73qJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EaCE73qJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_06PUTPOm, 0, m, &cDelay_06PUTPOm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaCE73qJ, 0, m, &cDelay_EaCE73qJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sTAENXFQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_06PUTPOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_06PUTPOm, m);
  cMsg_fViFmrpt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wb3rluwA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZM25GXMZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_aiXq7RAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TajVQ5kT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dsSyN1WZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T7k9b6dJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaCE73qJ, 2, m, &cDelay_EaCE73qJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GFsL275G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TajVQ5kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dsSyN1WZ, 0, m, &hTable_dsSyN1WZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LBXyUs2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_aiXq7RAj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fViFmrpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dsSyN1WZ, 0, m, &hTable_dsSyN1WZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_GFsL275G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaCE73qJ, 0, m, &cDelay_EaCE73qJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_T7k9b6dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_06PUTPOm, 2, m, &cDelay_06PUTPOm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZM25GXMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sTAENXFQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_4d3kI8dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyP12NAY, HV_BINOP_SUBTRACT, 0, m, &cBinop_qyP12NAY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1TQkYi04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3PXAoRg5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3PXAoRg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yXsYLydm_sendMessage);
}

void Heavy_ChaffVerb::cVar_DFw62a3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qdSE64Bc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_EsuSdWTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EsuSdWTp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OCxHb3h, 0, m, &cDelay_8OCxHb3h_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MipP36Ox, 0, m, &sTabread_MipP36Ox_sendMessage);
}

void Heavy_ChaffVerb::cDelay_8OCxHb3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8OCxHb3h, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MipP36Ox, 0, m, &sTabread_MipP36Ox_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OCxHb3h, 0, m, &cDelay_8OCxHb3h_sendMessage);
}

void Heavy_ChaffVerb::sTabread_MipP36Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_x0y05GiE, HV_BINOP_SUBTRACT, 0, m, &cBinop_x0y05GiE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_WOrt9548_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3lvAbo4, HV_BINOP_MAX, 0, m, &cBinop_V3lvAbo4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yXsYLydm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOrt9548, HV_BINOP_MULTIPLY, 0, m, &cBinop_WOrt9548_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qyP12NAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g9AUu1n7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MipP36Ox, 0, m, &sTabread_MipP36Ox_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UC4v1thR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aS5r0ZJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x0y05GiE, HV_BINOP_SUBTRACT, 1, m, &cBinop_x0y05GiE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OCxHb3h, 2, m, &cDelay_8OCxHb3h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qdSE64Bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aS5r0ZJN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g9AUu1n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsuSdWTp, 0, m, &cDelay_EsuSdWTp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OCxHb3h, 0, m, &cDelay_8OCxHb3h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d794r3qE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3lvAbo4, HV_BINOP_MAX, 1, m, &cBinop_V3lvAbo4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V3lvAbo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyP12NAY, HV_BINOP_SUBTRACT, 1, m, &cBinop_qyP12NAY_sendMessage);
}

void Heavy_ChaffVerb::cCast_UC4v1thR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsuSdWTp, 0, m, &cDelay_EsuSdWTp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WYRjCX88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsuSdWTp, 2, m, &cDelay_EsuSdWTp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x0y05GiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WYRjCX88_sendMessage);
}

void Heavy_ChaffVerb::cCast_KPAQfq7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DFw62a3j, 0, m, &cVar_DFw62a3j_sendMessage);
  cMsg_1TQkYi04_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4d3kI8dD, 0, m, &cTabhead_4d3kI8dD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_T6R4mb4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MyTy8UPL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MyTy8UPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_O4HOYGRS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sPjZ4urK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sPjZ4urK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hF6x7Pnd, 0, m, &cDelay_hF6x7Pnd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPjZ4urK, 0, m, &cDelay_sPjZ4urK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NvJKi4cG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hF6x7Pnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hF6x7Pnd, m);
  cMsg_8NGU57nz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_OMpGAplu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_idRnxbj6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_W34ABqyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ARzcHtr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_S3eQOCHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9YYYvpBR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPjZ4urK, 2, m, &cDelay_sPjZ4urK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UEpDhG7r_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6ARzcHtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_S3eQOCHV, 0, m, &hTable_S3eQOCHV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_O4HOYGRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_W34ABqyN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8NGU57nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_S3eQOCHV, 0, m, &hTable_S3eQOCHV_sendMessage);
}

void Heavy_ChaffVerb::cCast_UEpDhG7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPjZ4urK, 0, m, &cDelay_sPjZ4urK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9YYYvpBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hF6x7Pnd, 2, m, &cDelay_hF6x7Pnd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_idRnxbj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NvJKi4cG, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Fn576qfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbyJWY7v, HV_BINOP_SUBTRACT, 0, m, &cBinop_GbyJWY7v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2fzcbhTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vhYP4T34_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vhYP4T34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NJelFj86_sendMessage);
}

void Heavy_ChaffVerb::cVar_WPgvNL7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HBz3RkAS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_yLtTKDKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yLtTKDKz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TXNKxxsx, 0, m, &cDelay_TXNKxxsx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1qClPNA1, 0, m, &sTabread_1qClPNA1_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TXNKxxsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TXNKxxsx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1qClPNA1, 0, m, &sTabread_1qClPNA1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TXNKxxsx, 0, m, &cDelay_TXNKxxsx_sendMessage);
}

void Heavy_ChaffVerb::sTabread_1qClPNA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VkZ8c8wO, HV_BINOP_SUBTRACT, 0, m, &cBinop_VkZ8c8wO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lunaZG9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZZZLucn, HV_BINOP_MAX, 0, m, &cBinop_WZZZLucn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NJelFj86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lunaZG9Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_lunaZG9Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GbyJWY7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R4udq7Ew_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1qClPNA1, 0, m, &sTabread_1qClPNA1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zhdLqQUA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rMOXCuun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VkZ8c8wO, HV_BINOP_SUBTRACT, 1, m, &cBinop_VkZ8c8wO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TXNKxxsx, 2, m, &cDelay_TXNKxxsx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HBz3RkAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rMOXCuun_sendMessage);
}

void Heavy_ChaffVerb::cMsg_R4udq7Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yLtTKDKz, 0, m, &cDelay_yLtTKDKz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TXNKxxsx, 0, m, &cDelay_TXNKxxsx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qD6Sn4or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZZZLucn, HV_BINOP_MAX, 1, m, &cBinop_WZZZLucn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WZZZLucn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbyJWY7v, HV_BINOP_SUBTRACT, 1, m, &cBinop_GbyJWY7v_sendMessage);
}

void Heavy_ChaffVerb::cCast_zhdLqQUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yLtTKDKz, 0, m, &cDelay_yLtTKDKz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_McTENH53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yLtTKDKz, 2, m, &cDelay_yLtTKDKz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VkZ8c8wO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_McTENH53_sendMessage);
}

void Heavy_ChaffVerb::cCast_dMnOfy30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WPgvNL7F, 0, m, &cVar_WPgvNL7F_sendMessage);
  cMsg_2fzcbhTW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Fn576qfM, 0, m, &cTabhead_Fn576qfM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DHv3qEnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FBtEkSa8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FBtEkSa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HmDVlN8x_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zqtAKETY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zqtAKETY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsQ9LjG6, 0, m, &cDelay_YsQ9LjG6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zqtAKETY, 0, m, &cDelay_zqtAKETY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mrvpLTk5, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_YsQ9LjG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YsQ9LjG6, m);
  cMsg_PVLazNmU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_AduZBCFW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_tZF1jmLu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_pRrGVQnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m5AXFyuE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_XE09p89c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJ05Yuq2_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zqtAKETY, 2, m, &cDelay_zqtAKETY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K4NHeTcW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m5AXFyuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XE09p89c, 0, m, &hTable_XE09p89c_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HmDVlN8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_pRrGVQnY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PVLazNmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XE09p89c, 0, m, &hTable_XE09p89c_sendMessage);
}

void Heavy_ChaffVerb::cCast_K4NHeTcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zqtAKETY, 0, m, &cDelay_zqtAKETY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KJ05Yuq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_YsQ9LjG6, 2, m, &cDelay_YsQ9LjG6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tZF1jmLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mrvpLTk5, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_s7Yxg1vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRwc7Wr6, HV_BINOP_SUBTRACT, 0, m, &cBinop_NRwc7Wr6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a1UoHEbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fUFXvlaF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fUFXvlaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_b4KeL9JC_sendMessage);
}

void Heavy_ChaffVerb::cVar_zBopBGoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y05mrQFm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_zUlBAfs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zUlBAfs9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q88TBqLu, 0, m, &cDelay_q88TBqLu_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qxIjd7XQ, 0, m, &sTabread_qxIjd7XQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_q88TBqLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q88TBqLu, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qxIjd7XQ, 0, m, &sTabread_qxIjd7XQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q88TBqLu, 0, m, &cDelay_q88TBqLu_sendMessage);
}

void Heavy_ChaffVerb::sTabread_qxIjd7XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GIMmIxwz, HV_BINOP_SUBTRACT, 0, m, &cBinop_GIMmIxwz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_6UCy2FMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ttq0U8i, HV_BINOP_MAX, 0, m, &cBinop_3ttq0U8i_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b4KeL9JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6UCy2FMQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_6UCy2FMQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NRwc7Wr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z8KwcLD4_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qxIjd7XQ, 0, m, &sTabread_qxIjd7XQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E1fwUhR9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Bhjo8mn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIMmIxwz, HV_BINOP_SUBTRACT, 1, m, &cBinop_GIMmIxwz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q88TBqLu, 2, m, &cDelay_q88TBqLu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y05mrQFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Bhjo8mn6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Z8KwcLD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zUlBAfs9, 0, m, &cDelay_zUlBAfs9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q88TBqLu, 0, m, &cDelay_q88TBqLu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S7rgSv7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ttq0U8i, HV_BINOP_MAX, 1, m, &cBinop_3ttq0U8i_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3ttq0U8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRwc7Wr6, HV_BINOP_SUBTRACT, 1, m, &cBinop_NRwc7Wr6_sendMessage);
}

void Heavy_ChaffVerb::cCast_E1fwUhR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zUlBAfs9, 0, m, &cDelay_zUlBAfs9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y0coYbx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zUlBAfs9, 2, m, &cDelay_zUlBAfs9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GIMmIxwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y0coYbx6_sendMessage);
}

void Heavy_ChaffVerb::cCast_IRNOSpHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zBopBGoD, 0, m, &cVar_zBopBGoD_sendMessage);
  cMsg_a1UoHEbs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_s7Yxg1vO, 0, m, &cTabhead_s7Yxg1vO_sendMessage);
}

void Heavy_ChaffVerb::cVar_iLtp3u9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mLVPu7ku, 0, m, &cVar_mLVPu7ku_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HwCRFViA, 0, m, &cVar_HwCRFViA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GnJ3koTH, 0, m, &cVar_GnJ3koTH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VzR2tAHU, 0, m, &cVar_VzR2tAHU_sendMessage);
}

void Heavy_ChaffVerb::cVar_p9ed4s6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_lmGX2vOF_sendMessage);
}

void Heavy_ChaffVerb::cPack_ValzBxag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_YPcE17P9, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_HwCRFViA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_om40u9mW, HV_BINOP_MULTIPLY, 0, m, &cBinop_om40u9mW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RTnXbmAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uUlYflFy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uUlYflFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P46rXIZL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_om40u9mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hRVi0twL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PRchTMss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_om40u9mW, HV_BINOP_MULTIPLY, 1, m, &cBinop_om40u9mW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_P46rXIZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PRchTMss_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hRVi0twL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Bi3bZcDh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Bi3bZcDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_b9O07c7b_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CuNC0ETc, m);
}

void Heavy_ChaffVerb::cBinop_b9O07c7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EGx8QEf1, m);
}

void Heavy_ChaffVerb::cVar_GnJ3koTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TqRlPlFl, HV_BINOP_MULTIPLY, 0, m, &cBinop_TqRlPlFl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CJBV76bG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aE9dbXYA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aE9dbXYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sZ28OB32_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_TqRlPlFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cU2T4K8B_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jG9queRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TqRlPlFl, HV_BINOP_MULTIPLY, 1, m, &cBinop_TqRlPlFl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sZ28OB32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jG9queRJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cU2T4K8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LbgFu5Br_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LbgFu5Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Y1nSwRIC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5giHGhUr, m);
}

void Heavy_ChaffVerb::cBinop_Y1nSwRIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CaCtHWfh, m);
}

void Heavy_ChaffVerb::cVar_VzR2tAHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhV5hV5L, HV_BINOP_MULTIPLY, 0, m, &cBinop_bhV5hV5L_sendMessage);
}

void Heavy_ChaffVerb::cMsg_T2znHfxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rynb0B3M_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rynb0B3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SZCyUCCk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_bhV5hV5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_h7PmOsq0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TKkKzkAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhV5hV5L, HV_BINOP_MULTIPLY, 1, m, &cBinop_bhV5hV5L_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SZCyUCCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TKkKzkAq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h7PmOsq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cuQO1uJT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cuQO1uJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iYn3WLq6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZyPVMXzP, m);
}

void Heavy_ChaffVerb::cBinop_iYn3WLq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7BEeQR7m, m);
}

void Heavy_ChaffVerb::cBinop_DviahPZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_X68bxY3p, 0, m, &cPack_X68bxY3p_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XCQekIRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iLtp3u9Y, 0, m, &cVar_iLtp3u9Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lmGX2vOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ValzBxag, 0, m, &cPack_ValzBxag_sendMessage);
}

void Heavy_ChaffVerb::cBinop_70QQes9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_w5DLKjzJ, 0, m, &cPack_w5DLKjzJ_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_x7e1MLAC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_nk5jKiIh_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_nk5jKiIh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uqp8xIac_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_ega3sWn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ega3sWn7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ega3sWn7, 0, m, &cDelay_ega3sWn7_sendMessage);
  cSwitchcase_Ew1cUWot_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Uqp8xIac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nk5jKiIh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ega3sWn7, 0, m, &cDelay_ega3sWn7_sendMessage);
  cSwitchcase_Ew1cUWot_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Rb7XmLr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9AxhABM5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9AxhABM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xibJoGkN_sendMessage);
}

void Heavy_ChaffVerb::cVar_znezVLqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMns75k8, HV_BINOP_MULTIPLY, 0, m, &cBinop_fMns75k8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nk5jKiIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ega3sWn7, 0, m, &cDelay_ega3sWn7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vEJrimg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ega3sWn7, 2, m, &cDelay_ega3sWn7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xibJoGkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMns75k8, HV_BINOP_MULTIPLY, 1, m, &cBinop_fMns75k8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fMns75k8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vEJrimg1_sendMessage);
}

void Heavy_ChaffVerb::cVar_SBb9zEyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_8isOiGlp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_5KdZNSLK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_rw3U18an_sendMessage);
}

void Heavy_ChaffVerb::cVar_VhWx8tui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HNvuszse_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PMBeppMd, 0, m, &cIf_PMBeppMd_sendMessage);
}

void Heavy_ChaffVerb::cUnop_JbXqqW9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hm0bq0mm, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_hm0bq0mm_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Onv7cpNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hm0bq0mm, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_hm0bq0mm_sendMessage);
}

void Heavy_ChaffVerb::cIf_PMBeppMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Onv7cpNm_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_JbXqqW9t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_HNvuszse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PMBeppMd, 1, m, &cIf_PMBeppMd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bbt8YKd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0gClNZBk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0gClNZBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fYctclDV_sendMessage);
}

void Heavy_ChaffVerb::cDelay_UQChwJXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UQChwJXO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwKOkMAx, 0, m, &cDelay_dwKOkMAx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UQChwJXO, 0, m, &cDelay_UQChwJXO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QulgOzMA, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dwKOkMAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dwKOkMAx, m);
  cMsg_b7GrA6Zw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_vAYRESi0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_u8Ta7qDA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_5afmCjoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_siuNyk3j_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JnonAyLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ic4j5qZG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UQChwJXO, 2, m, &cDelay_UQChwJXO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oN5GxLFI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_siuNyk3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JnonAyLh, 0, m, &hTable_JnonAyLh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fYctclDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_5afmCjoi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b7GrA6Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JnonAyLh, 0, m, &hTable_JnonAyLh_sendMessage);
}

void Heavy_ChaffVerb::cCast_oN5GxLFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UQChwJXO, 0, m, &cDelay_UQChwJXO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ic4j5qZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwKOkMAx, 2, m, &cDelay_dwKOkMAx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_u8Ta7qDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QulgOzMA, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_8AmOYzRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rjnpq6V2, HV_BINOP_SUBTRACT, 0, m, &cBinop_rjnpq6V2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zCoj9E7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hdZ0dubA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hdZ0dubA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Uz3PgfLY_sendMessage);
}

void Heavy_ChaffVerb::cVar_Rh9cJxD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X66uU5Zk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_K47zZeV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K47zZeV6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9llOnsa, 0, m, &cDelay_k9llOnsa_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HNKgDQaO, 0, m, &sTabread_HNKgDQaO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_k9llOnsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k9llOnsa, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HNKgDQaO, 0, m, &sTabread_HNKgDQaO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9llOnsa, 0, m, &cDelay_k9llOnsa_sendMessage);
}

void Heavy_ChaffVerb::sTabread_HNKgDQaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_NieSwTh6, HV_BINOP_SUBTRACT, 0, m, &cBinop_NieSwTh6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_2J8j15Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKu9KkCs, HV_BINOP_MAX, 0, m, &cBinop_kKu9KkCs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Uz3PgfLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2J8j15Qm, HV_BINOP_MULTIPLY, 0, m, &cBinop_2J8j15Qm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rjnpq6V2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jT7bkXeC_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HNKgDQaO, 0, m, &sTabread_HNKgDQaO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3u8eT1R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CF4x53hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NieSwTh6, HV_BINOP_SUBTRACT, 1, m, &cBinop_NieSwTh6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9llOnsa, 2, m, &cDelay_k9llOnsa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X66uU5Zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CF4x53hW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jT7bkXeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_K47zZeV6, 0, m, &cDelay_K47zZeV6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9llOnsa, 0, m, &cDelay_k9llOnsa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ToZvdUcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKu9KkCs, HV_BINOP_MAX, 1, m, &cBinop_kKu9KkCs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kKu9KkCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rjnpq6V2, HV_BINOP_SUBTRACT, 1, m, &cBinop_rjnpq6V2_sendMessage);
}

void Heavy_ChaffVerb::cCast_H3u8eT1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K47zZeV6, 0, m, &cDelay_K47zZeV6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nIK5Fd7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K47zZeV6, 2, m, &cDelay_K47zZeV6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NieSwTh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nIK5Fd7n_sendMessage);
}

void Heavy_ChaffVerb::cCast_a08Bbolk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rh9cJxD5, 0, m, &cVar_Rh9cJxD5_sendMessage);
  cMsg_zCoj9E7M_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8AmOYzRE, 0, m, &cTabhead_8AmOYzRE_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_hdJodci8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BEsT172W_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_BEsT172W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UwgWMd7z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_IjJM4V0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IowUvDO0, HV_BINOP_ADD, 0, m, &cBinop_IowUvDO0_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_PTNcgO3k_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_arY2Wegz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_arY2Wegz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rXYrIowk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_m6cARmiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h85wTiFq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43aZAB8J_sendMessage);
}

void Heavy_ChaffVerb::cVar_H2dhAsBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IhbrJlPw, 0, m, &cVar_IhbrJlPw_sendMessage);
}

void Heavy_ChaffVerb::cVar_IhbrJlPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKS5cziW, HV_BINOP_ADD, 0, m, &cBinop_jKS5cziW_sendMessage);
}

void Heavy_ChaffVerb::cVar_puupe4C5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IBHa4cY5, HV_BINOP_ADD, 0, m, &cBinop_IBHa4cY5_sendMessage);
}

void Heavy_ChaffVerb::cVar_DQ18Zu3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YaZCiBjL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AI8o1Kli, 0, m, &cIf_AI8o1Kli_sendMessage);
}

void Heavy_ChaffVerb::cUnop_iYPVceXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IBHa4cY5, HV_BINOP_ADD, 1, m, &cBinop_IBHa4cY5_sendMessage);
}

void Heavy_ChaffVerb::cUnop_5jH0713d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IBHa4cY5, HV_BINOP_ADD, 1, m, &cBinop_IBHa4cY5_sendMessage);
}

void Heavy_ChaffVerb::cIf_AI8o1Kli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_5jH0713d_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_iYPVceXw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_YaZCiBjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AI8o1Kli, 1, m, &cIf_AI8o1Kli_sendMessage);
}

void Heavy_ChaffVerb::cVar_y4kRu06e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_twPqxV7C_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vl4Du1PH, 0, m, &cIf_vl4Du1PH_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ykE8zKqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mCHX5TNp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_ProyR6Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mCHX5TNp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_vl4Du1PH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_ProyR6Hj_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_ykE8zKqG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_twPqxV7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vl4Du1PH, 1, m, &cIf_vl4Du1PH_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_mCHX5TNp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qjO4SiWM, 0, m, &cSlice_qjO4SiWM_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_flEy9TUP, 0, m, &cSlice_flEy9TUP_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B6K6Y1al_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qb3bpTV2_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_qjO4SiWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZklkjtKR, 0, m, &cVar_ZklkjtKR_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZklkjtKR, 0, m, &cVar_ZklkjtKR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_flEy9TUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_63bY4m0g, HV_BINOP_NEQ, 1, m, &cBinop_63bY4m0g_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZklkjtKR, 1, m, &cVar_ZklkjtKR_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_63bY4m0g, HV_BINOP_NEQ, 1, m, &cBinop_63bY4m0g_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZklkjtKR, 1, m, &cVar_ZklkjtKR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_ZklkjtKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Quuq99dX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rbl4w04J_sendMessage);
}

void Heavy_ChaffVerb::cIf_2IGjtMut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LiioHxW0_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WXHBcvYG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_LiioHxW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_63bY4m0g, HV_BINOP_NEQ, 1, m, &cBinop_63bY4m0g_sendMessage);
}

void Heavy_ChaffVerb::cCast_WXHBcvYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZklkjtKR, 0, m, &cVar_ZklkjtKR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_63bY4m0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2IGjtMut, 1, m, &cIf_2IGjtMut_sendMessage);
}

void Heavy_ChaffVerb::cCast_Qb3bpTV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2IGjtMut, 0, m, &cIf_2IGjtMut_sendMessage);
}

void Heavy_ChaffVerb::cCast_B6K6Y1al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_63bY4m0g, HV_BINOP_NEQ, 0, m, &cBinop_63bY4m0g_sendMessage);
}

void Heavy_ChaffVerb::cIf_DfzZNqfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_mL4eL7gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_DfzZNqfc, 0, m, &cIf_DfzZNqfc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_Wy9NDlBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_DfzZNqfc, 0, m, &cIf_DfzZNqfc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_ZUntc9VP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_DfzZNqfc, 0, m, &cIf_DfzZNqfc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_DP8gvber_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_m6cARmiy, 0, m, &cVar_m6cARmiy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_sRrwJMGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puupe4C5, 0, m, &cVar_puupe4C5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AsGYfU5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mL4eL7gp, 1, m, &cIf_mL4eL7gp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iy1YaQZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZUntc9VP, 1, m, &cIf_ZUntc9VP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aWPJNeyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mL4eL7gp, 1, m, &cIf_mL4eL7gp_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Wy9NDlBD, 1, m, &cIf_Wy9NDlBD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZUntc9VP, 1, m, &cIf_ZUntc9VP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z4hvjGE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IjJM4V0y, 0, m, &cVar_IjJM4V0y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ytXIinyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Z4hvjGE6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rXYrIowk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_m6cARmiy, 0, m, &cVar_m6cARmiy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hm0bq0mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LuFczSeC, HV_BINOP_MULTIPLY, 0, m, &cBinop_LuFczSeC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rw3U18an_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hm0bq0mm, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_hm0bq0mm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N5lzR6wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Wy9NDlBD, 1, m, &cIf_Wy9NDlBD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IBHa4cY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S3vaOZMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yaebTX0s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TvcfVF5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yedrrxkn, 0, m, &cVar_Yedrrxkn_sendMessage);
}

void Heavy_ChaffVerb::cCast_yaebTX0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
}

void Heavy_ChaffVerb::cCast_S3vaOZMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvcfVF5j, HV_BINOP_ADD, 1, m, &cBinop_TvcfVF5j_sendMessage);
}

void Heavy_ChaffVerb::cCast_rbl4w04J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4PVtYCbu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Quuq99dX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aWPJNeyp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_yD69kkt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l8j2KzQ9, 0, m, &cVar_l8j2KzQ9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LuFczSeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wy9NDlBD, 0, m, &cIf_Wy9NDlBD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nfwHVAVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZUntc9VP, 0, m, &cIf_ZUntc9VP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YAjV78EG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fZXOetaC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_nfwHVAVg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8isOiGlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_vVZwB5iI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vVZwB5iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YAjV78EG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5KdZNSLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBb9zEyH, 1, m, &cVar_SBb9zEyH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8gfR6Tlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IEVN1eYC, 0, m, &cVar_IEVN1eYC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BMlhHqpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_znezVLqr, 0, m, &cVar_znezVLqr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UwgWMd7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IowUvDO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_co6RV58F, HV_BINOP_MULTIPLY, 0, m, &cBinop_co6RV58F_sendMessage);
}

void Heavy_ChaffVerb::cBinop_co6RV58F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DP8gvber, 0, m, &cIf_DP8gvber_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZvfQQpy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvcfVF5j, HV_BINOP_ADD, 0, m, &cBinop_TvcfVF5j_sendMessage);
}

void Heavy_ChaffVerb::cCast_h85wTiFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvfQQpy5, HV_BINOP_ADD, 1, m, &cBinop_ZvfQQpy5_sendMessage);
}

void Heavy_ChaffVerb::cCast_43aZAB8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
}

void Heavy_ChaffVerb::cCast_qRoT3nSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DfzZNqfc, 1, m, &cIf_DfzZNqfc_sendMessage);
}

void Heavy_ChaffVerb::cCast_INr0eVWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hdJodci8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Dagxqsxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IjJM4V0y, 0, m, &cVar_IjJM4V0y_sendMessage);
}

void Heavy_ChaffVerb::cCast_kwDMOKeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_co6RV58F, HV_BINOP_MULTIPLY, 1, m, &cBinop_co6RV58F_sendMessage);
}

void Heavy_ChaffVerb::cCast_y5gX2pJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DP8gvber, 1, m, &cIf_DP8gvber_sendMessage);
}

void Heavy_ChaffVerb::cCast_tCaLXnRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PTNcgO3k_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_7SjxYYkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IowUvDO0, HV_BINOP_ADD, 1, m, &cBinop_IowUvDO0_sendMessage);
}

void Heavy_ChaffVerb::cCast_7fdk5NHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IjJM4V0y, 0, m, &cVar_IjJM4V0y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IdaC0iZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvfQQpy5, HV_BINOP_ADD, 0, m, &cBinop_ZvfQQpy5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jKS5cziW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdaC0iZk, HV_BINOP_MULTIPLY, 0, m, &cBinop_IdaC0iZk_sendMessage);
}

void Heavy_ChaffVerb::cCast_49hsdzQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdaC0iZk, HV_BINOP_MULTIPLY, 1, m, &cBinop_IdaC0iZk_sendMessage);
}

void Heavy_ChaffVerb::cCast_YEvWYeYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
}

void Heavy_ChaffVerb::cCast_KELYWFzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H2dhAsBT, 0, m, &cVar_H2dhAsBT_sendMessage);
}

void Heavy_ChaffVerb::cCast_8TAZoPA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKS5cziW, HV_BINOP_ADD, 1, m, &cBinop_jKS5cziW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VjIRdb6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Quuq99dX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rbl4w04J_sendMessage);
}

void Heavy_ChaffVerb::cReceive_G7lQOA7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UB2ZegSV_sendMessage(_c, 0, m);
  cMsg_q47XnGeU_sendMessage(_c, 0, m);
  cMsg_VdZEjLNK_sendMessage(_c, 0, m);
  cMsg_MIFdkZeB_sendMessage(_c, 0, m);
  cMsg_T6R4mb4W_sendMessage(_c, 0, m);
  cMsg_DHv3qEnx_sendMessage(_c, 0, m);
  cMsg_JnOPKHnC_sendMessage(_c, 0, m);
  cMsg_SW7t7wQa_sendMessage(_c, 0, m);
  cMsg_V9pHsvuF_sendMessage(_c, 0, m);
  cMsg_zOWeDKNa_sendMessage(_c, 0, m);
  cMsg_U1vGPCXZ_sendMessage(_c, 0, m);
  cMsg_fdQY7HYU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mLVPu7ku, 0, m, &cVar_mLVPu7ku_sendMessage);
  cMsg_RTnXbmAR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HwCRFViA, 0, m, &cVar_HwCRFViA_sendMessage);
  cMsg_CJBV76bG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GnJ3koTH, 0, m, &cVar_GnJ3koTH_sendMessage);
  cMsg_T2znHfxz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VzR2tAHU, 0, m, &cVar_VzR2tAHU_sendMessage);
  cMsg_SXpljoXF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3q0Jcyol, 0, m, &cVar_3q0Jcyol_sendMessage);
  cMsg_oX1EbAmD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IEVN1eYC, 0, m, &cVar_IEVN1eYC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H3wDlbzV, 0, m, &cVar_H3wDlbzV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l8j2KzQ9, 0, m, &cVar_l8j2KzQ9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FJbdrw8s, 0, m, &cVar_FJbdrw8s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zdFYPJ2q, 0, m, &cVar_zdFYPJ2q_sendMessage);
  cMsg_Rb7XmLr3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_znezVLqr, 0, m, &cVar_znezVLqr_sendMessage);
  cMsg_Bbt8YKd7_sendMessage(_c, 0, m);
  cSwitchcase_qQJ9dGdI_onMessage(_c, NULL, 0, m, NULL);
  cMsg_UwgWMd7z_sendMessage(_c, 0, m);
  cMsg_VjIRdb6k_sendMessage(_c, 0, m);
  cMsg_rXYrIowk_sendMessage(_c, 0, m);
  cSwitchcase_x7e1MLAC_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_6T51SsZ3, 0, m, &cVar_6T51SsZ3_sendMessage);
  cMsg_z29I73fN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6tDQkw64, 0, m, &cVar_6tDQkw64_sendMessage);
  cMsg_1jYYRNr8_sendMessage(_c, 0, m);
  cMsg_gOuf8H5C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AFI9dnfK, 0, m, &cVar_AFI9dnfK_sendMessage);
  cMsg_OVU8L592_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_eflvBCvL, 0, m, &cTabhead_eflvBCvL_sendMessage);
  cMsg_wMduhJ4p_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_62gc3yjW, 0, m, &cVar_62gc3yjW_sendMessage);
  cMsg_eBTx9u9t_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_we6Ffhmv, 0, m, &cTabhead_we6Ffhmv_sendMessage);
  cMsg_OQLogK9B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_s43ZImzf, 0, m, &cVar_s43ZImzf_sendMessage);
  cMsg_QGUwlcgd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_pYjuD1Jl, 0, m, &cTabhead_pYjuD1Jl_sendMessage);
  cMsg_6uOdyVRb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_V8VzwWZs, 0, m, &cVar_V8VzwWZs_sendMessage);
  cMsg_cigfwYdD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9cmRcgH4, 0, m, &cTabhead_9cmRcgH4_sendMessage);
  cMsg_fizLJ01M_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uJ1HeKY7, 0, m, &cVar_uJ1HeKY7_sendMessage);
  cMsg_cmgcSoFq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_t6XdP8hy, 0, m, &cTabhead_t6XdP8hy_sendMessage);
  cMsg_WShJ9blQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_smL22Bux, 0, m, &cVar_smL22Bux_sendMessage);
  cMsg_iIybrJNC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_81nqNms3, 0, m, &cTabhead_81nqNms3_sendMessage);
  cMsg_40WSJGej_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_R2urZoI7, 0, m, &cVar_R2urZoI7_sendMessage);
  cMsg_VVRhIFY4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UnUc8etL, 0, m, &cTabhead_UnUc8etL_sendMessage);
  cMsg_d794r3qE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DFw62a3j, 0, m, &cVar_DFw62a3j_sendMessage);
  cMsg_1TQkYi04_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4d3kI8dD, 0, m, &cTabhead_4d3kI8dD_sendMessage);
  cMsg_qD6Sn4or_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WPgvNL7F, 0, m, &cVar_WPgvNL7F_sendMessage);
  cMsg_2fzcbhTW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Fn576qfM, 0, m, &cTabhead_Fn576qfM_sendMessage);
  cMsg_S7rgSv7h_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zBopBGoD, 0, m, &cVar_zBopBGoD_sendMessage);
  cMsg_a1UoHEbs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_s7Yxg1vO, 0, m, &cTabhead_s7Yxg1vO_sendMessage);
  cMsg_ToZvdUcL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Rh9cJxD5, 0, m, &cVar_Rh9cJxD5_sendMessage);
  cMsg_zCoj9E7M_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8AmOYzRE, 0, m, &cTabhead_8AmOYzRE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Vv8PnksE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_8gfR6Tlj_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QKq36wpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y4kRu06e, 0, m, &cVar_y4kRu06e_sendMessage);
}

void Heavy_ChaffVerb::cReceive_i0N34WD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VhWx8tui, 0, m, &cVar_VhWx8tui_sendMessage);
}

void Heavy_ChaffVerb::cReceive_dzd4aAt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LuFczSeC, HV_BINOP_MULTIPLY, 1, m, &cBinop_LuFczSeC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_lkpJ0FI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8TAZoPA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KELYWFzd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_XJBLCl3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_49hsdzQ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YEvWYeYA_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3UyH4f6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puupe4C5, 0, m, &cVar_puupe4C5_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Nl0Ix7ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sRrwJMGf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DQ18Zu3N, 0, m, &cVar_DQ18Zu3N_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4VStEtPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_BMlhHqpV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_nBMs12rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7SjxYYkP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7fdk5NHH_sendMessage);
}

void Heavy_ChaffVerb::cReceive_dmCiEhRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kwDMOKeS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dagxqsxn_sendMessage);
}

void Heavy_ChaffVerb::cReceive_lV6dMima_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y5gX2pJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tCaLXnRf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_yYFNFDOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wtYgI2PL, m);
}

void Heavy_ChaffVerb::cReceive_d88hy54u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NP36LcID, m);
}

void Heavy_ChaffVerb::cReceive_l43ru0xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H3wDlbzV, 0, m, &cVar_H3wDlbzV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ARlxh7Li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_yD69kkt1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_AV7kDxXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gZUGTgm6, 0, m, &cVar_gZUGTgm6_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LUoJe0Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fwb5ae2F, 0, m, &cVar_Fwb5ae2F_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZcLQ8oM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3q0Jcyol, 0, m, &cVar_3q0Jcyol_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tezUb3nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dBR2eu8q, m);
}

void Heavy_ChaffVerb::cReceive_STIqfz7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sor1q6Ay, m);
}

void Heavy_ChaffVerb::cReceive_DWYLUzoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2J8j15Qm, HV_BINOP_MULTIPLY, 1, m, &cBinop_2J8j15Qm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a08Bbolk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_z5sXHqBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qRoT3nSY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_INr0eVWA_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_ccAFn6rs, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_VbLGbSPu, VOf(Bf4));
    __hv_line_f(&sLine_Qel0Tz3o, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_grRbYKwb, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_JppLYqJG, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Xm2br7CB, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_vnMJTBPF, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_lcCbmPPB, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_SZRleZot, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_vEl8MDRo, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_ILpT1l4V, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_URptrByN, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_uf2chAfm, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ATDpSllt, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_sQ0SwIVa, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_cHAnGjC6, VIf(I0));
    __hv_varread_f(&sVarf_iuPD36f6, VOf(Bf2));
    __hv_rpole_f(&sRPole_RfBeyYXJ, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_xMHOJWIx, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_nyeDoN5b, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_dBR2eu8q, VOf(Bf1));
    __hv_tabread_f(&sTabread_HNKgDQaO, VOf(Bf5));
    __hv_varread_f(&sVarf_Sor1q6Ay, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_QulgOzMA, VIf(Bf9));
    __hv_varread_f(&sVarf_NP36LcID, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_CRiwZOJf, VOf(Bf9));
    __hv_varread_f(&sVarf_cZyj9lcf, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_ojOdSETX, VOf(Bf2));
    __hv_rpole_f(&sRPole_V0Dobz9U, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_YPcE17P9, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_5c5dYBmu, VOf(Bf2));
    __hv_tabread_f(&sTabread_8oOCCrlF, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_Etj4xFi4, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_T6J56BhL, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_MipP36Ox, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_qxIjd7XQ, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_1qClPNA1, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_g5XdYfUv, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_IAHxzDlc, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_05mLGdNx, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_sTAENXFQ, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_NvJKi4cG, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_mrvpLTk5, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_wJUHA0Xm, VOf(Bf9));
    __hv_varread_f(&sVarf_CuNC0ETc, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_EGx8QEf1, VOf(Bf3));
    __hv_rpole_f(&sRPole_We8uyL7C, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_H3Au2zq1, VOf(Bf3));
    __hv_varread_f(&sVarf_5giHGhUr, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_CaCtHWfh, VOf(Bf12));
    __hv_rpole_f(&sRPole_gD8hzrb4, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_OG6LvJkQ, VOf(Bf12));
    __hv_varread_f(&sVarf_ZyPVMXzP, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_7BEeQR7m, VOf(Bf11));
    __hv_rpole_f(&sRPole_KQF0tYQO, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_LMuAlumG, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_pFoZgzbg, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_NQlWomvF, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_Qng1z6EL, VIf(Bf11));
    __hv_line_f(&sLine_shf14V2b, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_wtYgI2PL, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
